@@ -1,6 +1,6 @@
 //===========================================================================
 // @(#) $Name:$
-// @(#) $Id: dwmrdap.cc 9458 2017-06-06 05:08:27Z dwm $
+// @(#) $Id: dwmrdap.cc 12239 2023-10-26 17:41:12Z dwm $
 //===========================================================================
 //  Copyright (c) Daniel W. McRobb 2017
 //  All rights reserved.
@@ -44,18 +44,16 @@
 #include <cstdio>
 #include <regex>
 
-#include <Poco/Net/SSLManager.h>
-#include <Poco/URI.h>
-
 #include "DwmDateTime.hh"
 #include "DwmIpv4Prefix.hh"
 #include "DwmOptArgs.hh"
 #include "DwmSvnTag.hh"
+#include "DwmSysLogger.hh"
 #include "DwmCountryCodes.hh"
 #include "DwmRDAPBootstrap.hh"
 #include "DwmRDAPQuery.hh"
 
-static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwmRDAP/tags/libDwmRDAP-0.2.1/apps/dwmrdap/dwmrdap.cc 9458 $");
+static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwmRDAP/tags/libDwmRDAP-0.3.3/apps/dwmrdap/dwmrdap.cc 12239 $");
 
 using namespace std;
 using namespace Dwm;
@@ -67,7 +65,7 @@ static void PrintResult(const RDAP::IPv4Response & result,
                         const CountryCodes & ccodes, bool verbose)
 {
   if (verbose) {
-    cout << result.toStyledString();
+    cout << result.dump(2);
   }
   else {
     pair<Ipv4Address,Ipv4Address>  &&addrs = result.AddressRange();
@@ -113,11 +111,10 @@ int main(int argc, char *argv[])
     return 1;
   }
 
-#if (POCO_VERSION >= 0x01040200)
-  Poco::Net::initializeSSL();
-#endif
-  
-  RDAP::Bootstrap::Load("file:///usr/local/etc/rdap_ipv4.json");
+  SysLogger::Open("dwmrdap", LOG_PERROR, LOG_USER);
+  SysLogger::MinimumPriority("debug");
+
+  RDAP::Bootstrap::Load("/usr/local/etc/rdap_ipv4.json");
   CountryCodes  ccodes;
   ccodes.ReadJson("/usr/local/etc/country_codes.json");
 
