@@ -1,6 +1,6 @@
 //===========================================================================
 // @(#) $Name:$
-// @(#) $Id: dwmrdapc.cc 11028 2020-08-28 06:56:02Z dwm $
+// @(#) $Id: dwmrdapc.cc 12126 2022-12-11 04:47:28Z dwm $
 //===========================================================================
 //  Copyright (c) Daniel W. McRobb 2017
 //  All rights reserved.
@@ -39,36 +39,21 @@
 //!  \brief dwmrdap client, mostly just an example
 //---------------------------------------------------------------------------
 
-extern "C" {
-  #include <sys/types.h>
-  #include <sys/socket.h>
-  #include <sys/stat.h>
-  #include <netinet/in.h>
-  #include <netinet/tcp.h>
-  #include <arpa/inet.h>
-  #include <fcntl.h>
-  #include <netdb.h>
-  #include <pwd.h>
-  #include <unistd.h>
-}
-
 #include <cstdlib>
 #include <fstream>
 #include <regex>
 #include <sstream>
 #include <string>
 
-#include "DwmIO.hh"
 #include "DwmIpv4Prefix.hh"
 #include "DwmOptArgs.hh"
-#include "DwmSocket.hh"
 #include "DwmSvnTag.hh"
 #include "DwmSysLogger.hh"
-#include "DwmAuthPeerAuthenticator.hh"
+#include "DwmCredencePeer.hh"
 #include "DwmRDAPRequestMessage.hh"
 #include "DwmRDAPResponseMessage.hh"
 
-static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwmRDAP/tags/libDwmRDAP-0.2.1/apps/dwmrdapc/dwmrdapc.cc 11028 $");
+static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwmRDAP/tags/libDwmRDAP-0.3.3/apps/dwmrdapc/dwmrdapc.cc 12126 $");
 
 using namespace std;
 using namespace Dwm;
@@ -76,57 +61,14 @@ using namespace Dwm;
 //----------------------------------------------------------------------------
 //!  
 //----------------------------------------------------------------------------
-static string GetHomeDirectory()
-{
-  string  rc;
-  uid_t   uid = geteuid();
-  struct passwd *pw = getpwuid(uid);
-  if (pw) {
-    rc = pw->pw_dir;
-  }
-  return rc;
-}
-
-//----------------------------------------------------------------------------
-//!  
-//----------------------------------------------------------------------------
-static string GetKeyDirectory()
-{
-  string  rc;
-  string  homeDir = GetHomeDirectory();
-  if (! homeDir.empty()) {
-    rc = homeDir + "/.dwmauth";
-  }
-  return rc;
-}
-
-//----------------------------------------------------------------------------
-//!  
-//----------------------------------------------------------------------------
-static bool Authenticate(Dwm::Socket & s, string & theirId, string & agreedKey)
-{
-  bool  rc = false;
-  Auth::PeerAuthenticator  peerAuth(GetKeyDirectory() + "/id_ed25519",
-                                    GetKeyDirectory() + "/known_services");
-  if (peerAuth.Authenticate(s, theirId, agreedKey)) {
-    rc = true;
-  }
-  return rc;
-}
-
-//----------------------------------------------------------------------------
-//!  
-//----------------------------------------------------------------------------
-string RequestResponse(Socket & s, const string & secret,
+string RequestResponse(Credence::Peer & peer,
                        const RDAP::RequestMessage & request)
 {
   string                  rc;
   RDAP::ResponseMessage   response;
-  Json::FastWriter        jfw;
-  if (request.Write(s, secret)) {
-    if (response.Read(s, secret)) {
-      // rc = jfw.write(response.Json());
-      rc = response.Json().toStyledString();
+  if (request.Write(peer)) {
+    if (response.Read(peer)) {
+      rc = response.Json().dump(2);
     }
     else {
       Syslog(LOG_ERR, "Failed to read server response");
@@ -141,13 +83,13 @@ string RequestResponse(Socket & s, const string & secret,
 //----------------------------------------------------------------------------
 //!  
 //----------------------------------------------------------------------------
-bool RequestResponse(Socket & s, const string & secret,
+bool RequestResponse(Credence::Peer & peer,
                      const RDAP::RequestMessage & request,
                      RDAP::ResponseMessage & response)
 {
   bool  rc = false;
-  if (request.Write(s, secret)) {
-    if (response.Read(s, secret)) {
+  if (request.Write(peer)) {
+    if (response.Read(peer)) {
       rc = true;
     }
     else {
@@ -160,55 +102,24 @@ bool RequestResponse(Socket & s, const string & secret,
   return rc;
 }
 
-//----------------------------------------------------------------------------
-//!  
-//----------------------------------------------------------------------------
-bool Connect(const string & host, Socket & s)
-{
-  bool  rc = false;
-  struct hostent  *hostEntry = gethostbyname2(host.c_str(), AF_INET);
-  if (! hostEntry) {
-    cerr << "Host '" << host << "' not found.\n";
-    exit(1);
-  }
-  
-  if (s.Open(PF_INET, SOCK_STREAM, 0)) {
-    struct sockaddr_in  servAddr;
-    memset(&servAddr, 0, sizeof(servAddr));
-#ifndef __linux__
-    servAddr.sin_len = sizeof(servAddr);
-#endif
-    servAddr.sin_family = AF_INET;
-    servAddr.sin_port = htons(6363);
-    servAddr.sin_addr.s_addr = *(in_addr_t *)hostEntry->h_addr_list[0];
-    if (s.Connect(servAddr)) {
-      int  noDelay = 1;
-      s.Setsockopt(IPPROTO_TCP, TCP_NODELAY, &noDelay, sizeof(noDelay));
-      rc = true;
-    }
-  }
-  return rc;
-}
-
 //----------------------------------------------------------------------------
 //!  
 //----------------------------------------------------------------------------
 static void Usage(const string & argv0)
 {
   cerr << "Usage: " << argv0 << " [-h host] IPv4_address\n";
-  //     << "       " << argv0 << " -h host createkeys\n";
   return;
 }
 
 //----------------------------------------------------------------------------
 //!  
 //----------------------------------------------------------------------------
-static bool Query(Socket & s, const string & secret,
+static bool Query(Credence::Peer & peer,
                   const vector<Ipv4Address> & addrs)
 {
   bool  rc = false;
   RDAP::RequestMessage  req(addrs);
-  string  resp = RequestResponse(s, secret, req);
+  string  resp = RequestResponse(peer, req);
   if (! resp.empty()) {
     cout << resp << '\n';
     rc = true;
@@ -219,7 +130,7 @@ static bool Query(Socket & s, const string & secret,
 //----------------------------------------------------------------------------
 //!  
 //----------------------------------------------------------------------------
-static bool Delete(Socket & s, const string & secret,
+static bool Delete(Credence::Peer & peer,
                    const vector<Ipv4Prefix> & prefixes)
 {
   bool  rc = false;
@@ -236,12 +147,10 @@ Ipv4Address NextWalkAddress(const Ipv4Prefix & prev, Ipv4Prefix & resp)
     addr = prev.FirstAddress();
     --addr;
     resp = Ipv4Prefix(addr, 24);
-    // cerr << "addr from short prefix: " << addr << '\n';
   }
   else {
     addr = resp.FirstAddress();
     --addr;
-    // cerr << "addr from good prefix: " << addr << '\n';
   }
   return addr;
 }
@@ -249,7 +158,7 @@ Ipv4Address NextWalkAddress(const Ipv4Prefix & prev, Ipv4Prefix & resp)
 //----------------------------------------------------------------------------
 //!  
 //----------------------------------------------------------------------------
-static void Walk(Socket & s, const string & secret, const Ipv4Prefix & pfx)
+static void Walk(Credence::Peer & peer, const Ipv4Prefix & pfx)
 {
   vector<Ipv4Address>  addrs;
   addrs.push_back(pfx.LastAddress());
@@ -257,13 +166,14 @@ static void Walk(Socket & s, const string & secret, const Ipv4Prefix & pfx)
   while (addrs[0] >= pfx.FirstAddress()) {
     RDAP::RequestMessage   req(addrs);
     RDAP::ResponseMessage  resp;
-    bool  rc = RequestResponse(s, secret, req, resp);
+    bool  rc = RequestResponse(peer, req, resp);
     if (rc) {
-      if (resp.Json()[0].isMember("prefix")
-          && resp.Json()[0]["prefix"].isString()) {
-        Ipv4Prefix  respPfx = Ipv4Prefix(resp.Json()[0]["prefix"].asString());
+      if ((resp.Json()[0].find("prefix") != resp.Json()[0].end())
+          && resp.Json()[0]["prefix"].is_string()) {
+        Ipv4Prefix  respPfx =
+          Ipv4Prefix(resp.Json()[0]["prefix"].get<string>());
         addrs[0] = NextWalkAddress(nextPfx, respPfx);
-        cout << resp.Json().toStyledString() << '\n';
+        cout << resp.Json().dump(2) << '\n';
         nextPfx = respPfx;
       }
       else {
@@ -315,30 +225,19 @@ int main(int argc, char *argv[])
     Usage(argv[0]);
     exit(1);
   }
-  
-  string  hostName;
-  struct hostent  *hostEntry =
-    gethostbyname2(rdapHost.c_str(), AF_INET);
-  if (hostEntry && hostEntry->h_name) {
-    hostName = hostEntry->h_name;
-  }
-  else {
-    cerr << "Failed to find host " << rdapHost << '\n';
-    Usage(argv[0]);
-    exit(1);
-  }
 
-  Socket  s;
-  string  theirId, secret;
-  if (Connect(hostName, s)) {
-    if (! Authenticate(s, theirId, secret)) {
-      cerr << "Failed to authenticate!\n";
-      return 1;
+  Credence::Peer  peer;
+  if (peer.Connect(rdapHost, 6363)) {
+    Credence::KeyStash   keyStash;
+    Credence::KnownKeys  knownKeys;
+    if (! peer.Authenticate(keyStash, knownKeys)) {
+      cerr << "Authentication failed\n";
+      exit(1);
     }
   }
   else {
-    cerr << "Failed to connect to " << hostName << '\n';
-    return 1;
+    cerr << "Failed to connect to " << rdapHost << '\n';
+    exit(1);
   }
   
   if (argc > nextArg) {
@@ -347,13 +246,13 @@ int main(int argc, char *argv[])
       for ( ; nextArg < argc; ++nextArg) {
         prefixes.push_back(Ipv4Prefix(argv[nextArg]));
       }
-      if (Delete(s, secret, prefixes)) {
+      if (Delete(peer, prefixes)) {
         rc = 0;
       }
     }
     else if (optargs.Get<bool>('w')) {
       for ( ; nextArg < argc; ++nextArg) {
-        Walk(s, secret, Ipv4Prefix(argv[nextArg]));
+        Walk(peer, Ipv4Prefix(argv[nextArg]));
       }
     }
     else {
@@ -361,7 +260,7 @@ int main(int argc, char *argv[])
       for ( ; nextArg < argc; ++nextArg) {
         addrs.push_back(Ipv4Address(argv[nextArg]));
       }
-      if (Query(s, secret, addrs)) {
+      if (Query(peer, addrs)) {
         rc = 0;
       }
     }
