@@ -1,6 +1,6 @@
 //===========================================================================
 // @(#) $Name:$
-// @(#) $Id: dwmrdapcc.cc 8919 2017-03-28 00:47:37Z dwm $
+// @(#) $Id: dwmrdapcc.cc 12128 2022-12-11 04:49:13Z dwm $
 //===========================================================================
 //  Copyright (c) Daniel W. McRobb 2017
 //  All rights reserved.
@@ -45,7 +45,7 @@
 #include "DwmSvnTag.hh"
 #include "DwmIpv4CountryDb.hh"
 
-static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwmRDAP/tags/libDwmRDAP-0.2.1/apps/dwmrdapcc/dwmrdapcc.cc 8919 $");
+static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwmRDAP/tags/libDwmRDAP-0.3.3/apps/dwmrdapcc/dwmrdapcc.cc 12128 $");
 
 using namespace std;
 using namespace Dwm;
@@ -55,7 +55,7 @@ using namespace Dwm;
 //----------------------------------------------------------------------------
 int main(int argc, char *argv[])
 {
-  Ipv4CountryDb  db;
+  Ipv4CountryDb  db("/usr/local/etc/ipv4country.db");
 
   vector<pair<Ipv4Prefix,Ipv4CountryDbValue>>  matches;
   Ipv4Address  addr(argv[1]);
