@@ -1,8 +1,8 @@
 //===========================================================================
 // @(#) $Name:$
-// @(#) $Id: DwmRDAPResponder.cc 9458 2017-06-06 05:08:27Z dwm $
+// @(#) $Id: DwmRDAPResponder.cc 12124 2022-12-11 04:45:09Z dwm $
 //===========================================================================
-//  Copyright (c) Daniel W. McRobb 2017
+//  Copyright (c) Daniel W. McRobb 2017, 2022
 //  All rights reserved.
 //
 //  Redistribution and use in source and binary forms, with or without
@@ -56,16 +56,13 @@ extern "C" {
 
 #include "DwmSysLogger.hh"
 #include "DwmSvnTag.hh"
-#include "DwmAuth.hh"
-#include "DwmAuthPeerAuthenticator.hh"
-#include "DwmAuthSymCryptoMessage.hh"
 #include "libDwmRDAPPortability.hh"
 #include "DwmRDAPQuery.hh"
 #include "DwmRDAPRequestMessage.hh"
 #include "DwmRDAPResponseMessage.hh"
-#include "DwmRDAPResponder.hh"
+#include "DwmRDAPServer.hh"
 
-static const Dwm::SvnTag  svntag("$DwmPath: dwm/libDwmRDAP/tags/libDwmRDAP-0.2.1/apps/dwmrdapd/DwmRDAPResponder.cc 9458 $");
+static const Dwm::SvnTag  svntag("$DwmPath: dwm/libDwmRDAP/tags/libDwmRDAP-0.3.3/apps/dwmrdapd/DwmRDAPResponder.cc 12124 $");
 
 using namespace std;
 
@@ -76,40 +73,48 @@ namespace Dwm {
     //------------------------------------------------------------------------
     //!  
     //------------------------------------------------------------------------
-    Responder::Responder(Socket & s, const string & myPrivKeyPath,
-                         const string & authorizedKeysPath,
-                         Ipv4CountryDb & db, const CountryCodes & cc)
-        : _db(db), _cc(cc), _socket(), _myPrivKeyPath(myPrivKeyPath),
-          _querySessions(), _authorizedKeysPath(authorizedKeysPath),
-          _run(true)
+    Responder::Responder(boost::asio::ip::tcp::socket && s, Server & server,
+                         const CountryCodes & cc)
+        : _peer(), _server(server), _db(server.GetDb()), _cc(cc),
+          _querySessions(), _running(false)
     {
-      if (s.Accept(_socket, _clientAddr)) {
-        Syslog(LOG_INFO, "Accepted connection from %s:%hu, fd %d",
-               inet_ntoa(_clientAddr.sin_addr), ntohs(_clientAddr.sin_port),
-               (int)_socket);
+      boost::system::error_code  ec;
+      s.native_non_blocking(false, ec);
+      _peer.SetKeyExchangeTimeout(chrono::milliseconds(2000));
+      _peer.SetIdExchangeTimeout(chrono::milliseconds(2000));
+      if (_peer.Accept(std::move(s))) {
         _thread = thread(&Responder::Run, this);
-        _running = true;
+        _running.store(true);
+      }
+      else {
+        _peer.Disconnect();
+        Syslog(LOG_ERR, "Failed to accept peer");
       }
     }
 
     //------------------------------------------------------------------------
     //!  
     //------------------------------------------------------------------------
-    bool Responder::Stop()
+    Responder::~Responder()
     {
-      _run = false;
-      return Join();
+      Join();
+      Syslog(LOG_INFO, "Responder destroyed for %s", _peer.Id().c_str());
     }
-    
+
     //------------------------------------------------------------------------
     //!  
     //------------------------------------------------------------------------
     bool Responder::Join()
     {
       bool  rc = false;
-      if (_thread.joinable() && (! _running)) {
-        _thread.join();
-        rc = true;
+      bool  isRunning = _running.load();
+      if (! isRunning) {
+        if (_thread.joinable()) {
+          _thread.join();
+          rc = true;
+          Syslog(LOG_DEBUG, "Joined thread for responder %s",
+                 _peer.Id().c_str());
+        }
       }
       return rc;
     }
@@ -117,21 +122,22 @@ namespace Dwm {
     //------------------------------------------------------------------------
     //!  
     //------------------------------------------------------------------------
-    bool Responder::IsValidQueryRequest(const Json::Value & request) const
+    bool Responder::IsValidQueryRequest(const nlohmann::json & request) const
     {
       bool  rc = false;
-      if (request.isMember("type")) {
-        if (request["type"].isString() && (request["type"] == "query")) {
-          if (request.isMember("ipv4addrs")
-              && request["ipv4addrs"].isArray()) {
+      if (request.find("type") != request.end()) {
+        if (request["type"].is_string()
+            && (request["type"].get<string>() == "query")) {
+          if ((request.find("ipv4addrs") != request.end())
+              && request["ipv4addrs"].is_array()) {
             int  i = 0;
             for ( ; i < request["ipv4addrs"].size(); ++i) {
-              if (! request["ipv4addrs"][i].isString()) {
+              if (! request["ipv4addrs"][i].is_string()) {
                 break;
               }
               struct in_addr  inAddr;
               if (inet_pton(AF_INET,
-                            request["ipv4addrs"][i].asString().c_str(),
+                            request["ipv4addrs"][i].get<string>().c_str(),
                             &inAddr) != 1) {
                 break;
               }
@@ -148,20 +154,22 @@ namespace Dwm {
     //------------------------------------------------------------------------
     //!  
     //------------------------------------------------------------------------
-    bool Responder::IsValidDeleteRequest(const Json::Value & request) const
+    bool Responder::IsValidDeleteRequest(const nlohmann::json & request) const
     {
       bool  rc = false;
-      if (request.isMember("type")) {
-        if (request["type"].isString() && (request["type"] == "delete")) {
-          if (request.isMember("prefixes") && request["prefixes"].isArray()) {
+      if (request.find("type") != request.end()) {
+        if (request["type"].is_string()
+            && (request["type"].get<string>() == "delete")) {
+          if ((request.find("prefixes") != request.end())
+              && request["prefixes"].is_array()) {
             int  i = 0;
             for ( ; i < request["prefixes"].size(); ++i) {
-              if (! request["prefixes"][i].isString()) {
+              if (! request["prefixes"][i].is_string()) {
                 break;
               }
               struct in_addr  inAddr;
               if (inet_net_pton(AF_INET,
-                                request["prefixes"][i].asString().c_str(),
+                                request["prefixes"][i].get<string>().c_str(),
                                 &inAddr, sizeof(inAddr)) == -1) {
                 break;
               }
@@ -178,7 +186,7 @@ namespace Dwm {
     //------------------------------------------------------------------------
     //!  
     //------------------------------------------------------------------------
-    bool Responder::IsValidRequest(const Json::Value & request) const
+    bool Responder::IsValidRequest(const nlohmann::json & request) const
     {
       return (IsValidQueryRequest(request)
               || IsValidDeleteRequest(request));
@@ -187,11 +195,11 @@ namespace Dwm {
     //------------------------------------------------------------------------
     //!  
     //------------------------------------------------------------------------
-    Json::Value
+    nlohmann::json
     Responder::DbMatchToJson(const Ipv4Address & addr,
                              const pair<Ipv4Prefix,Ipv4CountryDbValue> & match) const
     {
-      Json::Value  jv = match.second.Json();
+      nlohmann::json  jv = match.second.Json();
       jv["ipv4addr"] = (string)addr;
       jv["countryName"] = _cc.FindByCode(match.second.Code()).Name();
       jv["prefix"] = match.first.ToShortString();
@@ -201,9 +209,9 @@ namespace Dwm {
     //------------------------------------------------------------------------
     //!  
     //------------------------------------------------------------------------
-    Json::Value Responder::MulticastToJson(const Ipv4Address & addr)
+    nlohmann::json Responder::MulticastToJson(const Ipv4Address & addr)
     {
-      Json::Value  jv;
+      nlohmann::json  jv;
       DateTime  now(TimeValue64(true));
       jv["ipv4addr"] = (string)addr;
       jv["country"] = "22";
@@ -217,9 +225,9 @@ namespace Dwm {
     //------------------------------------------------------------------------
     //!  
     //------------------------------------------------------------------------
-    Json::Value Responder::PrivateToJson(const Ipv4Address & addr)
+    nlohmann::json Responder::PrivateToJson(const Ipv4Address & addr)
     {
-      Json::Value  jv;
+      nlohmann::json  jv;
       DateTime  now(TimeValue64(true));
       jv["ipv4addr"] = (string)addr;
       jv["country"] = "10";
@@ -233,9 +241,9 @@ namespace Dwm {
     //------------------------------------------------------------------------
     //!  
     //------------------------------------------------------------------------
-    Json::Value Responder::FutureToJson(const Ipv4Address & addr)
+    nlohmann::json Responder::FutureToJson(const Ipv4Address & addr)
     {
-      Json::Value  jv;
+      nlohmann::json  jv;
       DateTime  now(TimeValue64(true));
       jv["ipv4addr"] = (string)addr;
       jv["country"] = "24";
@@ -260,7 +268,7 @@ namespace Dwm {
     //!  
     //------------------------------------------------------------------------
     bool Responder::IsSpecialAddress(const Ipv4Address & addr,
-                                     Json::Value & jv)
+                                     nlohmann::json & jv)
     {
       bool  rc = false;
       vector<string> rdapServers = Bootstrap::RDAPServers(addr);
@@ -285,15 +293,16 @@ namespace Dwm {
     //------------------------------------------------------------------------
     //!  
     //------------------------------------------------------------------------
-    Json::Value Responder::HandleDeleteRequest(const Json::Value & request,
-                                               bool & dbupdated)
+    nlohmann::json
+    Responder::HandleDeleteRequest(const nlohmann::json & request,
+                                   bool & dbupdated)
     {
-      Json::Value  rc;
+      nlohmann::json  rc;
       dbupdated = false;
       Ipv4CountryDbValue  match;
       for (int i = 0; i < request["prefixes"].size(); ++i) {
-        if (request["prefixes"][i].isString()) {
-          Ipv4Prefix  pfx(request["prefixes"][i].asString());
+        if (request["prefixes"][i].is_string()) {
+          Ipv4Prefix  pfx(request["prefixes"][i].get<string>());
           if (! _db.Find(pfx, match)) {
             rc["prefixes"][i] = string(pfx.ToShortString() + " not found");
           }
@@ -313,20 +322,21 @@ namespace Dwm {
     //------------------------------------------------------------------------
     //!  
     //------------------------------------------------------------------------
-    Json::Value Responder::HandleQueryRequest(const Json::Value & request,
-                                              bool & dbupdated)
+    nlohmann::json
+    Responder::HandleQueryRequest(const nlohmann::json & request,
+                                  bool & dbupdated)
     {
-      Json::Value  rc;
+      nlohmann::json  rc;
       vector<Ipv4Address>  addrs;
       for (int i = 0; i < request["ipv4addrs"].size(); ++i) {
-        if (request["ipv4addrs"][i].isString()) {
-          addrs.push_back(Ipv4Address(request["ipv4addrs"][i].asString()));
+        if (request["ipv4addrs"][i].is_string()) {
+          addrs.push_back(Ipv4Address(request["ipv4addrs"][i].get<string>()));
         }
       }
       TimeValue64  expireTime(true);
       expireTime -= TimeValue64(90 * 24 * 60 * 60, 0);
       for (int i = 0; i < addrs.size(); ++i) {
-        Json::Value  dbVal;
+        nlohmann::json  dbVal;
         pair<Ipv4Prefix,Ipv4CountryDbValue>  match;
         if (IsSpecialAddress(addrs[i], rc[i])) {
         }
@@ -359,10 +369,10 @@ namespace Dwm {
     //------------------------------------------------------------------------
     //!  
     //------------------------------------------------------------------------
-    Json::Value Responder::HandleRequest(const Json::Value & request,
-                                         bool & dbupdated)
+    nlohmann::json Responder::HandleRequest(const nlohmann::json & request,
+                                            bool & dbupdated)
     {
-      Json::Value       rc;
+      nlohmann::json       rc;
       if (IsValidQueryRequest(request)) {
         rc = HandleQueryRequest(request, dbupdated);
       }
@@ -371,8 +381,7 @@ namespace Dwm {
       }
       else {
         if (SysLogger::MinimumPriority() >= LOG_DEBUG) {
-          Json::FastWriter  fw;
-          Syslog(LOG_DEBUG, "invalid request %s", fw.write(request).c_str());
+          Syslog(LOG_DEBUG, "invalid request %s", request.dump().c_str());
         }
       }
       return rc;
@@ -384,46 +393,29 @@ namespace Dwm {
     void Responder::Run()
     {
       set_pthread_name(_thread.native_handle(), "responder");
-      Syslog(LOG_DEBUG, "Responder started on fd %d", (int)_socket);
-      Json::Reader      jsonReader;
-      Json::FastWriter  fw;
       RequestMessage    reqMsg;
       bool              savedb = false;
 
-      int  noDelay = 1;
-      _socket.Setsockopt(IPPROTO_TCP, TCP_NODELAY, &noDelay, sizeof(noDelay));
-      Auth::PeerAuthenticator  peerAuth(_myPrivKeyPath, _authorizedKeysPath);
-      string  theirId;
-      if (peerAuth.Authenticate(_socket, theirId, _agreedKey)) {
-        Syslog(LOG_INFO, "Authenticated client %s from %s:%hu",
-               theirId.c_str(), inet_ntoa(_clientAddr.sin_addr),
-               ntohs(_clientAddr.sin_port));
-      }
-      else {
-        Syslog(LOG_INFO, "Authentication failed for client from %s:%hu",
-               inet_ntoa(_clientAddr.sin_addr), ntohs(_clientAddr.sin_port));
-        goto responderDone;
-      }
-
-      while (_run && (reqMsg.Read(_socket, _agreedKey) > 0)) {
-        bool  dbupdated = false;
-        const Json::Value  &reqJson = reqMsg.Json();
-        Json::Value  &&respJson = HandleRequest(reqJson, dbupdated);
-        if (dbupdated) {
-          savedb = true;
+      Syslog(LOG_INFO, "Responder started");
+      if (_peer.Authenticate(_server.GetKeyStash(), _server.GetKnownKeys())) {
+        while (reqMsg.Read(_peer)) {
+          bool  dbupdated = false;
+          const nlohmann::json  & reqJson = reqMsg.Json();
+          nlohmann::json  respJson = HandleRequest(reqJson, dbupdated);
+          if (dbupdated) {
+            savedb = true;
+          }
+          ResponseMessage respMsg(respJson);
+          if (! respMsg.Write(_peer)) {
+            break;
+          }
         }
-        ResponseMessage respMsg(respJson);
-        if (! respMsg.Write(_socket, _agreedKey)) {
-          break;
+        if (savedb) {
+          _db.Save();
         }
       }
-      if (savedb) {
-        _db.Save();
-      }
-    responderDone:
       _running = false;
-      Syslog(LOG_INFO, "Done with client %s:%hu",
-             inet_ntoa(_clientAddr.sin_addr), ntohs(_clientAddr.sin_port));
+      Syslog(LOG_INFO, "Responder done");
       return;
     }
 
