@@ -1,6 +1,6 @@
 //===========================================================================
 // @(#) $Name:$
-// @(#) $Id: DwmRDAPServerConfig.cc 9002 2017-04-10 06:39:25Z dwm $
+// @(#) $Id: DwmRDAPServerConfig.cc 12073 2022-11-24 05:17:58Z dwm $
 //===========================================================================
 //  Copyright (c) Daniel W. McRobb 2017
 //  All rights reserved.
@@ -42,7 +42,7 @@
 #include "DwmSvnTag.hh"
 #include "DwmRDAPServerConfig.hh"
 
-static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwmRDAP/tags/libDwmRDAP-0.2.1/apps/dwmrdapd/DwmRDAPServerConfig.cc 9002 $");
+static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwmRDAP/tags/libDwmRDAP-0.3.3/apps/dwmrdapd/DwmRDAPServerConfig.cc 12073 $");
 
 using namespace std;
 
@@ -72,10 +72,10 @@ namespace Dwm {
     Ipv4Address ServerConfig::TCPAddress() const
     {
       Ipv4Address  rc(INADDR_ANY);
-      const Json::Value *val = _cfg2json.Find("Server/TCP/Address");
+      const nlohmann::json *val = _cfg2json.Find("Server/TCP/Address");
       if (val) {
-        if (val->isString() && (val->asString() != "any")) {
-          rc = Ipv4Address(val->asString());
+        if (val->is_string() && (val->get<string>() != "any")) {
+          rc = Ipv4Address(val->get<string>());
         }
       }
       return rc;
@@ -87,10 +87,11 @@ namespace Dwm {
     uint16_t ServerConfig::TCPPort() const
     {
       uint16_t  rc = 6363;
-      const Json::Value *val = _cfg2json.Find("Server/TCP/Port");
+      const nlohmann::json *val = _cfg2json.Find("Server/TCP/Port");
       if (val) {
-        if (val->isUInt() && (val->asUInt() <= 65535) && (val->asUInt() > 0)) {
-          rc = val->asUInt();
+        if (val->is_number_unsigned()
+            && (val->get<uint64_t>() <= 65535) && (val->get<uint64_t>() > 0)) {
+          rc = val->get<uint16_t>();
         }
       }
       return rc;
@@ -153,10 +154,10 @@ namespace Dwm {
                                     const string & deflt) const
     {
       string  rc(deflt);
-      const Json::Value *val = _cfg2json.Find(path);
+      const nlohmann::json  *val = _cfg2json.Find(path);
       if (val) {
-        if (val->isString() && (! val->asString().empty())) {
-          rc = val->asString();
+        if (val->is_string() && (! val->get<string>().empty())) {
+          rc = val->get<string>();
         }
       }
       return rc;
@@ -168,10 +169,10 @@ namespace Dwm {
     bool ServerConfig::ConfBool(const string & path, bool dflt) const
     {
       bool  rc(dflt);
-      const Json::Value *val = _cfg2json.Find(path);
+      const nlohmann::json  *val = _cfg2json.Find(path);
       if (val) {
-        if (val->isString() && (! val->asString().empty())) {
-          rc = (val->asString() == "true") ? true : false;
+        if (val->is_string() && (! val->get<string>().empty())) {
+          rc = (val->get<string>() == "true") ? true : false;
         }
       }
       return rc;
