@@ -1,6 +1,6 @@
 //===========================================================================
 // @(#) $Name:$
-// @(#) $Id: dwmrdapd.cc 11028 2020-08-28 06:56:02Z dwm $
+// @(#) $Id: dwmrdapd.cc 12080 2022-11-26 05:48:39Z dwm $
 //===========================================================================
 //  Copyright (c) Daniel W. McRobb 2017
 //  All rights reserved.
@@ -51,8 +51,6 @@ extern "C" {
 
 #include <cstdio>
 
-#include <Poco/Net/SSLManager.h>
-
 #include "DwmDaemonUtils.hh"
 #include "DwmOptArgs.hh"
 #include "DwmSignal.hh"
@@ -62,11 +60,14 @@ extern "C" {
 #include "DwmRDAPServerConfig.hh"
 #include "DwmRDAPServer.hh"
 
-static const Dwm::SvnTag  svntag("@(#) $DwmPath: dwm/libDwmRDAP/tags/libDwmRDAP-0.2.1/apps/dwmrdapd/dwmrdapd.cc 11028 $");
+static const Dwm::SvnTag  svntag("@(#) $DwmPath: dwm/libDwmRDAP/tags/libDwmRDAP-0.3.3/apps/dwmrdapd/dwmrdapd.cc 12080 $");
 
 using namespace std;
 using namespace Dwm;
 
+boost::asio::io_context  g_serverContext;
+static atomic<bool>      g_gotSigTerm = false;
+
 //----------------------------------------------------------------------------
 //!  
 //----------------------------------------------------------------------------
@@ -85,6 +86,33 @@ static void SavePID(const std::string & pidFile)
   return;
 }
 
+//----------------------------------------------------------------------------
+//!  
+//----------------------------------------------------------------------------
+static void SigTermHandler(int sigNum)
+{
+  if (SIGTERM == sigNum) {
+    g_gotSigTerm = true;
+    g_serverContext.stop();
+    Syslog(LOG_INFO, "SigTermHandler got SIGTERM");
+  }
+  return;
+}
+
+//----------------------------------------------------------------------------
+//!  
+//----------------------------------------------------------------------------
+static void BoostSignalHandler(const boost::system::error_code & ec,
+                               int sigNum)
+{
+  if (SIGTERM == sigNum) {
+    g_gotSigTerm = true;
+    g_serverContext.stop();
+    Syslog(LOG_INFO, "BoostSignalHandler got SIGTERM");
+  }
+  return;
+}
+
 //----------------------------------------------------------------------------
 //!  
 //----------------------------------------------------------------------------
@@ -105,9 +133,6 @@ int main(int argc, char *argv[])
   Signal SigPipe(SIGPIPE);
   SigPipe.Block();
 
-  Signal SigTerm(SIGTERM);
-  SigTerm.Block();
-
   string  pidFile = optargs.Get<string>('p');
   if (pidFile.empty()) {
     pidFile = "/var/run/dwmrdapd.pid";
@@ -122,35 +147,37 @@ int main(int argc, char *argv[])
   int  rc = 1;
   RDAP::ServerConfig  serverConfig(configFile);
   if (serverConfig.Parse()) {
-#if (POCO_VERSION >= 0x01040200)
-    Poco::Net::initializeSSL();
-#endif
     SysLogger::Open("dwmrdapd", logOpts, serverConfig.SyslogFacility());
     SysLogger::MinimumPriority(serverConfig.SyslogMinimumPriority());
     SysLogger::ShowFileLocation(serverConfig.SyslogShowFileLocations());
 
     RDAP::Bootstrap::Load(serverConfig.RDAPIpv4BootstrapFile());
-
-    RDAP::Server  server("/usr/local/etc/dwmrdapd/id_ed25519",
-                         "/usr/local/etc/dwmrdapd/authorized_keys",
+    
+    Signal sigTerm(SIGTERM);
+    sigTerm.PushHandler(SigTermHandler);
+    boost::asio::signal_set boostSignals(g_serverContext, SIGTERM);
+    boostSignals.async_wait(BoostSignalHandler);
+    
+    RDAP::Server  server(g_serverContext.get_executor(),
+                         "/usr/local/etc/dwmrdapd",
                          serverConfig);
-    if (server.Start()) {
-      for (;;) {
-        sleep(1);
-        if (SigTerm.IsPending()) {
-          break;
-        }
+    g_serverContext.run();
+    for (;;) {
+      if (g_gotSigTerm) {
+        server.Stop();
+        break;
+      }
+      else {
+        this_thread::sleep_for(chrono::milliseconds(500));
       }
-      server.Stop();
-      rc = 0;
     }
+    rc = 0;
   }
   else {
-    Syslog(LOG_ERR, "Failed to parse config file!");
+    cerr << "failed to parse configuration in '" << configFile << "'\n";
     rc = 1;
   }
-
   remove(pidFile.c_str());
-  return rc;
+  return 0;
 }
 
