@@ -1,6 +1,6 @@
 //===========================================================================
-// @(#) $DwmPath: dwm/libDwmRDAP/tags/libDwmRDAP-0.2.1/apps/getpfx2as/getpfx2as.cc 9604 $
-// @(#) $Id: getpfx2as.cc 9604 2017-06-22 19:36:47Z dwm $
+// @(#) $DwmPath: dwm/libDwmRDAP/tags/libDwmRDAP-0.3.3/apps/getpfx2as/getpfx2as.cc 12241 $
+// @(#) $Id: getpfx2as.cc 12241 2023-10-26 17:59:43Z dwm $
 //===========================================================================
 //  Copyright (c) Daniel W. McRobb 2017
 //  All rights reserved.
@@ -49,6 +49,7 @@ extern "C" {
 #include <iostream>
 #include <iomanip>
 #include <regex>
+#include <sstream>
 #include <tuple>
 #include <vector>
 
@@ -56,66 +57,47 @@ extern "C" {
 #include <boost/iostreams/copy.hpp>
 #include <boost/iostreams/filter/gzip.hpp>
 
-#include <Poco/Net/HTTPClientSession.h>
-#include <Poco/Net/HTTPRequest.h>
-#include <Poco/Net/HTTPResponse.h>
-#include <Poco/URI.h>
-
 #include "DwmIpv4Routes.hh"
 #include "DwmSvnTag.hh"
+#include "DwmWebUtils.hh"
+#include "DwmWebUtilsUrl.hh"
 
-static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwmRDAP/tags/libDwmRDAP-0.2.1/apps/getpfx2as/getpfx2as.cc 9604 $");
+static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwmRDAP/tags/libDwmRDAP-0.3.3/apps/getpfx2as/getpfx2as.cc 12241 $");
 
 using namespace std;
+using namespace boost::beast;
 using boost::iostreams::filtering_streambuf;
 using boost::iostreams::gzip_decompressor;
 using boost::iostreams::gzip_compressor;
-using Poco::URI;
-using Poco::Net::HTTPClientSession;
-using Poco::Net::HTTPMessage;
-using Poco::Net::HTTPRequest;
-using Poco::Net::HTTPResponse;
 
 typedef std::tuple<int,time_t,string>  DataFileTuple;
 
 //----------------------------------------------------------------------------
 //!  baseURL should be
-//!  http://data.caida.org/datasets/routing/routeviews-prefix2as
+//!  https://data.caida.org/datasets/routing/routeviews-prefix2as
 //----------------------------------------------------------------------------
 vector<DataFileTuple> GetAvailableFiles(const string & baseURL)
 {
   vector<DataFileTuple>  dataFiles;
+  std::string         fullUri = baseURL + "/pfx2as-creation.log";
+  http::response<http::string_body>  resp;
   
-  Poco::URI          uri(baseURL + "/pfx2as-creation.log");
-  HTTPClientSession  sess(uri.getHost());
-  HTTPRequest        req(HTTPRequest::HTTP_GET, uri.getPathAndQuery(),
-                         HTTPMessage::HTTP_1_1);
-  try {
-    std::regex   rgx("([0-9]+)[ \t]+([0-9]+)[ \t]+([^ \t]+)",
-                     regex::ECMAScript|regex::optimize);
-    std::smatch  sm;
-    ostream & os = sess.sendRequest(req);
-    if (os) {
-      HTTPResponse  resp;
-      istream & is = sess.receiveResponse(resp);
-      string  s;
-      while (getline(is, s)) {
-        if (regex_search(s, sm, rgx)) {
-          if (sm.size() == 4) {
-            DataFileTuple  dft(stoi(sm[1].str()), stoull(sm[2].str()),
-                               sm[3].str());
-            dataFiles.push_back(dft);
-          }
+  if (Dwm::WebUtils::GetResponse(fullUri, resp)) {
+    std::regex     rgx("([0-9]+)[ \t]+([0-9]+)[ \t]+([^ \t]+)",
+                       regex::ECMAScript|regex::optimize);
+    std::smatch    sm;
+    istringstream  is(resp.body());
+    string         s;
+    while (getline(is, s)) {
+      if (regex_search(s, sm, rgx)) {
+        if (sm.size() == 4) {
+          DataFileTuple  dft(stoi(sm[1].str()), stoull(sm[2].str()),
+                             sm[3].str());
+          dataFiles.push_back(dft);
         }
       }
     }
   }
-  catch (Poco::Exception &ex) {
-    cerr << "Exception, URI "
-         << uri.toString() << ", " << ex.className() << ", "
-         << ex.name() << ", " << ex.displayText() << "\n";
-  }
-
   return dataFiles;
 }
 
@@ -146,23 +128,10 @@ bool GetDataFile(const string & baseURL, const string & fileRelPath,
     outFileName = fileRelPath.substr(idx + 1);
     ofstream  ofs(outFileName.c_str());
     if (ofs) {
-      Poco::URI          uri(baseURL + '/' + fileRelPath);
-      HTTPClientSession  sess(uri.getHost());
-      HTTPRequest        req(HTTPRequest::HTTP_GET, uri.getPathAndQuery(),
-                             HTTPMessage::HTTP_1_1);
-      try {
-        ostream & os = sess.sendRequest(req);
-        if (os) {
-          HTTPResponse  resp;
-          istream & is = sess.receiveResponse(resp);
-          ofs << is.rdbuf();
-          rc = true;
-        }
-      }
-      catch (Poco::Exception &ex) {
-        cerr << "Exception, URI "
-             << uri.toString() << ", " << ex.className() << ", "
-             << ex.name() << ", " << ex.displayText() << "\n";
+      string  fullURL = baseURL + '/' + fileRelPath;
+      http::response<http::string_body>  resp;
+      if (Dwm::WebUtils::GetResponse(fullURL, resp)) {
+        ofs << resp.body();
       }
       ofs.close();
     }
@@ -197,7 +166,7 @@ bool CoalesceDataFile(const string & inFileName, string & outFileName)
       filtering_streambuf<boost::iostreams::output>  gzout;
       gzout.push(gzip_compressor(boost::iostreams::zlib::best_compression));
       gzout.push(os);
-      ostream  gzos(&gzout);
+      std::ostream  gzos(&gzout);
 
       Dwm::Ipv4Routes<string>  routes;
       string  addrstr, maskstr, asnumstr;
@@ -328,12 +297,30 @@ void Usage(const string & argv0)
   return;
 }
 
+//----------------------------------------------------------------------------
+//!  
+//----------------------------------------------------------------------------
+bool CoalesceGivenFile(const string & inFile)
+{
+  bool  rc = false;
+  vector<string>  fileNames({inFile});
+  if (CoalesceDataFiles(fileNames)) {
+    if (CreatePrefix2ASFiles(fileNames)) {
+      rc = true;
+    }
+  }
+  return rc;
+}
+
 //----------------------------------------------------------------------------
 //!  Fetches and coalesces a CAIDA prefix to AS file, for example:
-//!  http://data.caida.org/datasets/routing/routeviews-prefix2as/2017/06/routeviews-rv2-20170614-1200.pfx2as.gz
+//!  https://data.caida.org/datasets/routing/routeviews-prefix2as/2017/06/routeviews-rv2-20170614-1200.pfx2as.gz
 //----------------------------------------------------------------------------
 int main(int argc, char *argv[])
 {
+  CoalesceGivenFile(argv[1]);
+  return 0;
+  
   int     rc = 1;
   bool    getall = false;
   bool    createBinFile = false;
@@ -362,7 +349,7 @@ int main(int argc, char *argv[])
     }
   }
   
-  string  baseURL("http://data.caida.org/datasets/routing/routeviews-prefix2as");
+  string  baseURL("https://data.caida.org/datasets/routing/routeviews-prefix2as");
   vector<DataFileTuple>  fileTuples = GetAvailableFiles(baseURL);
   vector<string>         fileNames;
   if (! fileTuples.empty()) {
