@@ -1,6 +1,6 @@
 //===========================================================================
 // @(#) $Name:$
-// @(#) $Id: rdapdb2pf.cc 8957 2017-04-03 04:49:45Z dwm $
+// @(#) $Id: rdapdb2pf.cc 12241 2023-10-26 17:59:43Z dwm $
 //===========================================================================
 //  Copyright (c) Daniel W. McRobb 2017
 //  All rights reserved.
@@ -43,7 +43,7 @@
 #include "DwmSvnTag.hh"
 #include "DwmIpv4CountryDb.hh"
 
-static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwmRDAP/tags/libDwmRDAP-0.2.1/apps/rdapdb2pf/rdapdb2pf.cc 8957 $");
+static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwmRDAP/tags/libDwmRDAP-0.3.3/apps/rdapdb2pf/rdapdb2pf.cc 12241 $");
 
 using namespace std;
 using namespace Dwm;
@@ -53,16 +53,20 @@ using namespace Dwm;
 //----------------------------------------------------------------------------
 int main(int argc, char *argv[])
 {
-  if (argc == 3) {
-    Ipv4CountryDb  countrydb(argv[1]);
+  if (argc >= 3) {
+    Ipv4CountryDb   countrydb(argv[1]);
+    vector<string>  countryCodes;
+    for (int i = 2; i < argc; ++i) {
+      countryCodes.push_back(argv[i]);
+    }
     vector<Ipv4Prefix>  &&prefixes =
-      countrydb.PrefixesForCountries(argv[2], true);
+      countrydb.PrefixesForCountries(countryCodes);
     for (auto const & pfx : prefixes) {
       cout << pfx << '\n';
     }
   }
   else {
-    cerr << "Usage: " << argv[0] << " dbfile regexp\n";
+    cerr << "Usage: " << argv[0] << " dbfile countryCode(s)...\n";
     return 1;
   }
   return 0;
