@@ -1,6 +1,6 @@
 //===========================================================================
 // @(#) $Name:$
-// @(#) $Id: rdapjson2db.cc 9407 2017-06-03 03:51:33Z dwm $
+// @(#) $Id: rdapjson2db.cc 12077 2022-11-25 18:56:56Z dwm $
 //===========================================================================
 //  Copyright (c) Daniel W. McRobb 2017
 //  All rights reserved.
@@ -45,7 +45,7 @@
 #include "DwmSvnTag.hh"
 #include "DwmIpv4CountryDb.hh"
 
-static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwmRDAP/tags/libDwmRDAP-0.2.1/apps/rdapjson2db/rdapjson2db.cc 9407 $");
+static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwmRDAP/tags/libDwmRDAP-0.3.3/apps/rdapjson2db/rdapjson2db.cc 12077 $");
 
 using namespace std;
 using namespace Dwm;
@@ -60,20 +60,19 @@ int main(int argc, char *argv[])
     return 1;
   }
   
-  Json::Reader  jr;
-  Json::Value   jv;
   ifstream  is(argv[1]);
   if (is) {
     Dwm::Ipv4CountryDb countrydb(argv[2]);
-    if (jr.parse(is, jv)) {
+    nlohmann::json  jv = nlohmann::json::parse(is, nullptr, false);
+    if (! jv.is_discarded()) {
       for (int i = 0; i < jv.size(); ++i) {
         DateTime  dt(Dwm::TimeValue64(0,0));
-        if (jv[i].isMember("lastChanged")) {
-          dt.Parse(jv[i]["lastChanged"].asString(), "%Y-%m-%d %H:%M");
+        if ((jv[i].find("lastChanged") != jv[i].end())) {
+          dt.Parse(jv[i]["lastChanged"].get<string>(), "%Y-%m-%d %H:%M");
         }
-        Ipv4CountryDbValue  value(jv[i]["country"].asString(),
+        Ipv4CountryDbValue  value(jv[i]["country"].get<string>(),
                                   dt.GetTimeValue64());
-        ((RDAP::Ipv4Routes<Ipv4CountryDbValue> &)countrydb).Add(Ipv4Prefix(jv[i]["prefix"].asString()), value);
+        ((RDAP::Ipv4Routes<Ipv4CountryDbValue> &)countrydb).Add(Ipv4Prefix(jv[i]["prefix"].get<string>()), value);
       }
       countrydb.Save();
     }
