@@ -1,6 +1,6 @@
 //===========================================================================
 // @(#) $Name:$
-// @(#) $Id: DwmCountryCodes.cc 8916 2017-03-27 23:56:59Z dwm $
+// @(#) $Id: DwmCountryCodes.cc 12073 2022-11-24 05:17:58Z dwm $
 //===========================================================================
 //  Copyright (c) Daniel W. McRobb 2017
 //  All rights reserved.
@@ -41,13 +41,16 @@
 
 #include <regex>
 
-#include <json/json.h>
+#include <nlohmann/json.hpp>
 
-#include "DwmIO.hh"
+#include "DwmDescriptorIO.hh"
+#include "DwmFileIO.hh"
+#include "DwmIOUtils.hh"
+#include "DwmStreamIO.hh"
 #include "DwmSvnTag.hh"
 #include "DwmCountryCodes.hh"
 
-static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwmRDAP/tags/libDwmRDAP-0.2.1/src/DwmCountryCodes.cc 8916 $");
+static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwmRDAP/tags/libDwmRDAP-0.3.3/src/DwmCountryCodes.cc 12073 $");
 
 using namespace std;
 
@@ -102,6 +105,30 @@ namespace Dwm {
     
     ifstream  is(fileName.c_str());
     if (is) {
+      nlohmann::json  jv = nlohmann::json::parse(is, nullptr, false);
+      if (! jv.is_discarded()) {
+        auto  cit = jv.find("codes");
+        if ((cit != jv.end()) && (cit->is_array())) {
+          for (auto & el : *cit) {
+            CountryCode  cc(el);
+            if ((cc.Alpha2().length() == 2)
+                && (cc.Alpha3().length() == 3)
+                && (! cc.Name().empty())) {
+              _a2toCountryCode[cc.Alpha2()] = cc;
+              _a3toCountryCode[cc.Alpha3()] = cc;
+            }
+            else {
+              cerr << "cc.Alpha2(): " << cc.Alpha2()
+                   << " cc.Alpha3(): " << cc.Alpha3()
+                   << " cc.Name(): " << cc.Name() << '\n';
+            }
+          }
+        }
+      }
+      is.close();
+    }
+#if 0
+      
       Json::Reader  jr;
       Json::Value   jv;
       if (jr.parse(is, jv)) {
@@ -119,6 +146,7 @@ namespace Dwm {
       }
       is.close();
     }
+#endif
     return (! _a2toCountryCode.empty());
   }
   
@@ -130,14 +158,14 @@ namespace Dwm {
     bool  rc = false;
     ofstream  os(filename.c_str());
     if (os) {
-      Json::Value  jv;
+      nlohmann::json  jv;
       jv["description"] = string("ISO country codes");
       int  i = 0;
       for (auto & cci : _a2toCountryCode) {
         jv["codes"][i] = cci.second.Json();
         ++i;
       }
-      os << Json::StyledWriter().write(jv);
+      os << jv;
       if (os) {
         rc = true;
       }
@@ -152,7 +180,7 @@ namespace Dwm {
   istream & CountryCodes::Read(istream & is)
   {
     _a3toCountryCode.clear();
-    IO::Read(is, _a2toCountryCode);
+    StreamIO::Read(is, _a2toCountryCode);
     if (! _a2toCountryCode.empty()) {
       for (auto & cc : _a2toCountryCode) {
         _a3toCountryCode[cc.second.Alpha3()] = cc.second;
@@ -167,7 +195,7 @@ namespace Dwm {
   ssize_t CountryCodes::Read(int fd)
   {
     _a3toCountryCode.clear();
-    ssize_t  rc = IO::Read(fd, _a2toCountryCode);
+    ssize_t  rc = DescriptorIO::Read(fd, _a2toCountryCode);
     if (! _a2toCountryCode.empty()) {
       for (auto & cc : _a2toCountryCode) {
         _a3toCountryCode[cc.second.Alpha3()] = cc.second;
@@ -182,7 +210,7 @@ namespace Dwm {
   size_t CountryCodes::Read(FILE *f)
   {
     _a3toCountryCode.clear();
-    size_t  rc = IO::Read(f, _a2toCountryCode);
+    size_t  rc = FileIO::Read(f, _a2toCountryCode);
     if (! _a2toCountryCode.empty()) {
       for (auto & cc : _a2toCountryCode) {
         _a3toCountryCode[cc.second.Alpha3()] = cc.second;
@@ -196,7 +224,7 @@ namespace Dwm {
   //--------------------------------------------------------------------------
   ostream & CountryCodes::Write(ostream & os) const
   {
-    return IO::Write(os, _a2toCountryCode);
+    return StreamIO::Write(os, _a2toCountryCode);
   }
 
   //--------------------------------------------------------------------------
@@ -204,7 +232,7 @@ namespace Dwm {
   //--------------------------------------------------------------------------
   ssize_t CountryCodes::Write(int fd) const
   {
-    return IO::Write(fd, _a2toCountryCode);
+    return DescriptorIO::Write(fd, _a2toCountryCode);
   }
 
   //--------------------------------------------------------------------------
@@ -212,15 +240,15 @@ namespace Dwm {
   //--------------------------------------------------------------------------
   size_t CountryCodes::Write(FILE *f) const
   {
-    return IO::Write(f, _a2toCountryCode);
+    return FileIO::Write(f, _a2toCountryCode);
   }
   
   //--------------------------------------------------------------------------
   //!  
   //--------------------------------------------------------------------------
-  uint32_t CountryCodes::StreamedLength() const
+  uint64_t CountryCodes::StreamedLength() const
   {
-    return IO::StreamedLength(_a2toCountryCode);
+    return IOUtils::StreamedLength(_a2toCountryCode);
   }
   
 
