@@ -1,6 +1,6 @@
 //===========================================================================
 // @(#) $Name:$
-// @(#) $Id: DwmIpv4CountryDb.cc 9458 2017-06-06 05:08:27Z dwm $
+// @(#) $Id: DwmIpv4CountryDb.cc 12241 2023-10-26 17:59:43Z dwm $
 //===========================================================================
 //  Copyright (c) Daniel W. McRobb 2017
 //  All rights reserved.
@@ -60,7 +60,7 @@ extern "C" {
 #include "DwmSysLogger.hh"
 #include "DwmIpv4CountryDb.hh"
 
-static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwmRDAP/tags/libDwmRDAP-0.2.1/src/DwmIpv4CountryDb.cc 9458 $");
+static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwmRDAP/tags/libDwmRDAP-0.3.3/src/DwmIpv4CountryDb.cc 12241 $");
 
 using namespace std;
 
@@ -88,7 +88,7 @@ namespace Dwm {
   //--------------------------------------------------------------------------
   //!  
   //--------------------------------------------------------------------------
-  Ipv4CountryDbValue::Ipv4CountryDbValue(const Json::Value & rdapResponse)
+  Ipv4CountryDbValue::Ipv4CountryDbValue(const nlohmann::json & rdapResponse)
   {
 
   }
@@ -229,7 +229,7 @@ namespace Dwm {
   //--------------------------------------------------------------------------
   //!  
   //--------------------------------------------------------------------------
-  uint32_t Ipv4CountryDbValue::StreamedLength() const
+  uint64_t Ipv4CountryDbValue::StreamedLength() const
   {
     return IO::StreamedLength(_data);
   }
@@ -245,9 +245,9 @@ namespace Dwm {
   //--------------------------------------------------------------------------
   //!  
   //--------------------------------------------------------------------------
-  Json::Value Ipv4CountryDbValue::Json() const
+  nlohmann::json Ipv4CountryDbValue::Json() const
   {
-    Json::Value  jv;
+    nlohmann::json  jv;
     DateTime  lastUpdated(LastUpdated());
     DateTime  lastChanged(LastChanged());
 
@@ -262,22 +262,24 @@ namespace Dwm {
   //!  
   //--------------------------------------------------------------------------
   Ipv4CountryDb::Ipv4CountryDb(const std::string & filename)
-      : Ipv4Routes<Ipv4CountryDbValue>(), _filename(filename)
+      : RDAP::Ipv4Routes<Ipv4CountryDbValue>(), _filename(filename)
   {
-    int	 fd = open(_filename.c_str(), O_RDONLY|O_SHLOCK);
-    if (fd >= 0) {
+    if (! _filename.empty()) {
+      int	 fd = open(_filename.c_str(), O_RDONLY|O_SHLOCK);
+      if (fd >= 0) {
 #ifdef __linux__
-      flock(fd, LOCK_SH);
+        flock(fd, LOCK_SH);
 #endif
-      Read(fd);
-      close(fd);
+        Read(fd);
+        close(fd);
+      }
     }
   }
 
   //--------------------------------------------------------------------------
   //!  
   //--------------------------------------------------------------------------
-  bool Ipv4CountryDb::Add(const RDAP::IPv4Response & rdapResponse)
+  bool Ipv4CountryDb::AddEntry(const RDAP::IPv4Response & rdapResponse)
   {
     bool  rc = false;
     pair<Ipv4Address,Ipv4Address>  &&addrs = rdapResponse.AddressRange();
@@ -292,7 +294,7 @@ namespace Dwm {
         vector<Ipv4Prefix>  &&prefixes =
           Ipv4RangePrefixes(addrs.first, addrs.second);
         for (auto & pfx : prefixes) {
-          ((Ipv4Routes<Ipv4CountryDbValue> *)this)->Add(pfx, value);
+          Add(pfx, value);
           rc = true;
         }
       }
@@ -322,39 +324,21 @@ namespace Dwm {
         for (auto & pfx : prefixes) {
           Ipv4CountryDbValue  prevValue;
           if (Find(pfx, prevValue)) {
+            //  Replace existing entry.
             Delete(pfx);
             DeleteCoveredExpired(pfx, expireDays);
-            rc = ((Ipv4Routes<Ipv4CountryDbValue> *)this)->Add(pfx, value);
+            rc = Add(pfx, value);
             if (rc) {
-              Syslog(LOG_INFO, "Updated %s", pfx.ToShortString().c_str());
+              Syslog(LOG_INFO, "Updated %s (%s)",
+                     pfx.ToShortString().c_str(), country.c_str());
             }
-#if 0
-            if (prevValue.LastUpdated() < dt.GetTimeValue64()) {
-              //  existing entry is old.  Replace it.
-              // lock_guard<shared_mutex>  lock(_mtx);
-              Delete(pfx);
-              rc = ((Ipv4Routes<Ipv4CountryDbValue> *)this)->Add(pfx, value);
-              if (rc) {
-                Syslog(LOG_INFO, "Updated %s", pfx.ToShortString().c_str());
-              }
-            }
-            else if (prevValue.Code() != value.Code()) {
-              //  country in existing db entry is incorrect.
-              // lock_guard<mutex>  lock(_mtx);
-              Delete(pfx);
-              rc = ((Ipv4Routes<Ipv4CountryDbValue> *)this)->Add(pfx, value);
-              if (rc) {
-                Syslog(LOG_INFO, "Updated %s", pfx.ToShortString().c_str());
-              }
-            }
-#endif
           }
           else {
             //  No existing entry found, add it.
-            // lock_guard<mutex>  lock(_mtx);
-            rc = ((Ipv4Routes<Ipv4CountryDbValue> *)this)->Add(pfx, value);
+            rc = Add(pfx, value);
             if (rc) {
-              Syslog(LOG_INFO, "Added %s", pfx.ToShortString().c_str());
+              Syslog(LOG_INFO, "Added %s (%s)",
+                     pfx.ToShortString().c_str(), country.c_str());
             }
           }
         }
@@ -452,7 +436,7 @@ namespace Dwm {
   void Ipv4CountryDb::PrintJson(ostream & os) const
   {
     if (os) {
-      Json::Value  jv;
+      nlohmann::json  jv;
       vector<pair<Ipv4Prefix,Ipv4CountryDbValue>>  entries;
       SortByKey(entries);
       for (uint32_t i = 0; i < entries.size(); ++i) {
@@ -467,7 +451,7 @@ namespace Dwm {
         jv[i]["lastUpdated"] = lastUpdated;
         jv[i]["lastChanged"] = lastChanged;
       }
-      os << jv.toStyledString();
+      os << jv.dump();
     }
   }
 
@@ -501,6 +485,7 @@ namespace Dwm {
   //--------------------------------------------------------------------------
   void Ipv4CountryDb::DeleteRedundantSpecifics()
   {
+#if 0
     lock_guard<shared_mutex>  lock(this->_mtx);
     for (int i = 32; i > 0; --i) {
       auto  hm = _maps[i];
@@ -517,6 +502,7 @@ namespace Dwm {
         }
       }
     }
+#endif
     return;
   }
 
@@ -535,7 +521,8 @@ namespace Dwm {
   //!  
   //--------------------------------------------------------------------------
   vector<Ipv4Prefix>
-  Ipv4CountryDb::PrefixesForCountries(const vector<string> & countries)
+  Ipv4CountryDb::PrefixesForCountries(const vector<string> & countries,
+                                      bool minimalSet)
   {
     vector<Ipv4Prefix>  rc;
     uint8_t             masklen = 0;
@@ -551,6 +538,11 @@ namespace Dwm {
       }
       ++masklen;
     }
+    if (minimalSet) {
+      CoalesceContainedPrefixes(rc);
+      sort(rc.begin(), rc.end());
+      CoalesceAdjacentPrefixes(rc);
+    }
     return rc;
   }
 
