@@ -1,6 +1,6 @@
 //===========================================================================
 // @(#) $Name:$
-// @(#) $Id: DwmRDAPBootstrap.cc 9306 2017-05-08 09:04:02Z dwm $
+// @(#) $Id: DwmRDAPBootstrap.cc 12122 2022-12-11 04:42:58Z dwm $
 //===========================================================================
 //  Copyright (c) Daniel W. McRobb 2017
 //  All rights reserved.
@@ -44,38 +44,20 @@
 #include <iomanip>
 #include <string>
 
-#include <Poco/Net/PrivateKeyPassphraseHandler.h>
-#include <Poco/Net/HTTPClientSession.h>
-#include <Poco/Net/HTTPSClientSession.h>
-#include <Poco/Net/HTTPRequest.h>
-#include <Poco/Net/HTTPResponse.h>
-#include <Poco/Net/SSLManager.h>
-#include <Poco/Net/ConsoleCertificateHandler.h>
-#include <Poco/URI.h>
-
 #include "DwmSvnTag.hh"
+#include "DwmSysLogger.hh"
+#include "DwmWebUtils.hh"
+#include "DwmWebUtilsUrl.hh"
 #include "DwmRDAPBootstrap.hh"
 
-static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwmRDAP/tags/libDwmRDAP-0.2.1/src/DwmRDAPBootstrap.cc 9306 $");
+static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwmRDAP/tags/libDwmRDAP-0.3.3/src/DwmRDAPBootstrap.cc 12122 $");
 
 using namespace std;
-using Poco::URI;
-using Poco::Net::HTTPClientSession;
-using Poco::Net::HTTPSClientSession;
-using Poco::Net::HTTPMessage;
-using Poco::Net::HTTPRequest;
-using Poco::Net::HTTPResponse;
-using Poco::Net::Context;
 
 namespace Dwm {
 
   namespace RDAP {
 
-    static Context::Ptr  g_context =
-      new Context(Context::CLIENT_USE, "", "", "",
-                  Context::VERIFY_NONE, 9, false,
-                  "ALL:!ADH:!LOW:!EXP:!MD5:@STRENGTH");
-
     std::mutex                             Bootstrap::_mtx;
     Ipv4Routes<std::vector<std::string> >  Bootstrap::_addrs2rdaps;
 
@@ -102,14 +84,15 @@ namespace Dwm {
     {
       {
         lock_guard<mutex>  lock(_mtx);
+
         _addrs2rdaps.Clear();
-        Json::Value  &&jv = GetJsonResponse(bootstrapURI);
+        nlohmann::json  jv = GetJsonResponse(bootstrapURI);
         for (int s = 0; s < jv["services"].size(); ++s) {
           for (int n = 0; n < jv["services"][s][0].size(); ++n) {
             for (int rds = 0; rds < jv["services"][s][1].size(); ++rds) {
               vector<string> & e =
-                _addrs2rdaps[Ipv4Prefix(jv["services"][s][0][n].asString())];
-              e.push_back(jv["services"][s][1][rds].asString());
+                _addrs2rdaps[Ipv4Prefix(jv["services"][s][0][n].get<string>())];
+              e.push_back(jv["services"][s][1][rds].get<string>());
               sort(e.begin(), e.end());
             }
           }
@@ -159,43 +142,33 @@ namespace Dwm {
     //------------------------------------------------------------------------
     //!  
     //------------------------------------------------------------------------
-    Json::Value Bootstrap::GetJsonResponse(const std::string & uristr)
+    nlohmann::json Bootstrap::GetJsonResponse(const std::string & uristr)
     {
-      Poco::URI    uri(uristr);
-      Json::Value  rc;
-      std::string  host(uri.getHost());
-      std::string  path(uri.getPathAndQuery());
-      HTTPClientSession    *sess;
-      if (uri.getScheme() == "file") {
-        ifstream  is(path.c_str());
-        if (is) {
-          Json::Reader  reader;
-          reader.parse(is, rc);
+      nlohmann::json  rc;
+      WebUtils::Url   url;
+      if (url.Parse(uristr)) {
+        if (url.Scheme() == "file") {
+          std::string  path(url.Path());
+          ifstream     is(path.c_str());
+          if (is) {
+            rc = nlohmann::json::parse(is, nullptr, false);
+          }
+          return rc;
+        }
+        else if ((url.Scheme() == "https")
+                 || (url.Scheme() == "http")) {
+          WebUtils::GetJson(uristr, rc);
         }
-        return rc;
-      }
-      else if (uri.getScheme() == "https") {
-        sess = new HTTPSClientSession(host, uri.getPort(), g_context);
       }
       else {
-        sess = new HTTPClientSession(host);
-      }
-      HTTPRequest  req(HTTPRequest::HTTP_GET, path, HTTPMessage::HTTP_1_1);
-      try {
-        ostream & os = sess->sendRequest(req);
-        if (os) {
-          HTTPResponse  resp;
-          istream  & is = sess->receiveResponse(resp);
-          Json::Reader  reader;
-          reader.parse(is, rc);
+        std::ifstream  is(uristr);
+        if (is) {
+          rc = nlohmann::json::parse(is, nullptr, false);
+        }
+        else {
+          Syslog(LOG_ERR, "Failed to open '%s'", uristr.c_str());
         }
       }
-      catch (Poco::Exception &ex) {
-        cerr << "Exception in sess.receiveResponse, URI "
-             << uri.toString() << ", " << ex.className() << ", "
-             << ex.name() << ", " << ex.displayText() << "\n";
-      }
-      delete sess;
       return rc;
     }
 
