@@ -1,6 +1,6 @@
 //===========================================================================
 // @(#) $Name:$
-// @(#) $Id: DwmRDAPFetcher.cc 9458 2017-06-06 05:08:27Z dwm $
+// @(#) $Id: DwmRDAPFetcher.cc 12123 2022-12-11 04:44:23Z dwm $
 //===========================================================================
 //  Copyright (c) Daniel W. McRobb 2017
 //  All rights reserved.
@@ -36,25 +36,15 @@
 
 //---------------------------------------------------------------------------
 //!  \file DwmRDAPFetcher.cc
-//!  \brief NOT YET DOCUMENTED
+//!  \brief Dwm::RDAP::Fetcher class implementation
 //---------------------------------------------------------------------------
 
-extern "C" {
-  #include <sys/types.h>
-  #include <sys/socket.h>
-  #include <netinet/in.h>
-  #include <netinet/tcp.h>
-  #include <arpa/inet.h>
-  #include <netdb.h>
-}
-
 #include "DwmDateTime.hh"
 #include "DwmSvnTag.hh"
 #include "DwmSysLogger.hh"
-#include "DwmAuthPeerAuthenticator.hh"
 #include "DwmRDAPFetcher.hh"
 
-static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwmRDAP/tags/libDwmRDAP-0.2.1/src/DwmRDAPFetcher.cc 9458 $");
+static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwmRDAP/tags/libDwmRDAP-0.3.3/src/DwmRDAPFetcher.cc 12123 $");
 
 using namespace std;
 
@@ -127,7 +117,6 @@ namespace Dwm {
     //!  
     //------------------------------------------------------------------------
     Fetcher::Fetcher()
-        : _rdapSocket(), _agreedKey()
     {}
 
     //------------------------------------------------------------------------
@@ -142,49 +131,23 @@ namespace Dwm {
     //!  
     //------------------------------------------------------------------------
     bool Fetcher::OpenSession(const string & rdapServer,
-                              const string & privKeyPath,
-                              const string & knownServicesPath)
+                              const Credence::KeyStash & keyStash,
+                              const Credence::KnownKeys & knownKeys)
     {
       bool  rc = false;
       
       if (! rdapServer.empty()) {
-        struct hostent  *hostEntry =
-          gethostbyname2(rdapServer.c_str(), AF_INET);
-        if (hostEntry) {
-          struct sockaddr_in  servAddr;
-          memset(&servAddr, 0, sizeof(servAddr));
-#ifndef __linux__
-          servAddr.sin_len = sizeof(servAddr);
-#endif
-          servAddr.sin_family = AF_INET;
-          servAddr.sin_port = htons(6363);
-          servAddr.sin_addr.s_addr = *(in_addr_t *)hostEntry->h_addr_list[0];
-          if (_rdapSocket.Open(PF_INET, SOCK_STREAM, 0)) {
-            if (_rdapSocket.Connect(servAddr)) {
-              Auth::PeerAuthenticator  peer(privKeyPath, knownServicesPath);
-              string  theirId;
-              if (peer.Authenticate(_rdapSocket, theirId, _agreedKey)) {
-                rc = true;
-              }
-              else {
-                _rdapSocket.Close();
-                Syslog(LOG_ERR, "Failed to authenticate to dwmrdapd@%s",
-                       rdapServer.c_str());
-              }
-            }
-            else {
-              _rdapSocket.Close();
-              Syslog(LOG_ERR, "Failed to connect to dwmrdapd@%s",
-                     rdapServer.c_str());
-            }
+        if (_peer.Connect(rdapServer, 6363)) {
+          if (_peer.Authenticate(keyStash, knownKeys)) {
+            rc = true;
           }
           else {
-            Syslog(LOG_ERR, "Failed to open socket for dwmrdapd@%s",
+            Syslog(LOG_ERR, "Authentication to %s failed",
                    rdapServer.c_str());
           }
         }
         else {
-          Syslog(LOG_ERR, "Unknown dwmrdapd host %s", rdapServer.c_str());
+          Syslog(LOG_ERR, "Failed to connect to %s", rdapServer.c_str());
         }
       }
       return rc;
@@ -197,11 +160,9 @@ namespace Dwm {
                                   RDAP::ResponseMessage & response)
     {
       bool  rc = false;
-      if (_rdapSocket) {
-        if (request.Write(_rdapSocket, _agreedKey)) {
-          if (response.Read(_rdapSocket, _agreedKey)) {
-            rc = true;
-          }
+      if (request.Write(_peer)) {
+        if (response.Read(_peer)) {
+          rc = true;
         }
       }
       return rc;
@@ -210,16 +171,16 @@ namespace Dwm {
     //------------------------------------------------------------------------
     //!  
     //------------------------------------------------------------------------
-    bool Fetcher::ResponseEntryHasData(const Json::Value & jv)
+    bool Fetcher::ResponseEntryHasData(const nlohmann::json & jv)
     {
-      return (jv.isMember("ipv4addr")
-              && jv["ipv4addr"].isString()
-              && jv.isMember("prefix")
-              && jv["prefix"].isString()
-              && jv.isMember("country")
-              && jv["country"].isString()
-              && jv.isMember("lastUpdated")
-              && jv["lastUpdated"].isString());
+      return ((jv.find("ipv4addr") != jv.end())
+              && jv["ipv4addr"].is_string()
+              && (jv.find("prefix") != jv.end())
+              && jv["prefix"].is_string()
+              && (jv.find("country") != jv.end())
+              && jv["country"].is_string()
+              && (jv.find("lastUpdated") != jv.end())
+              && jv["lastUpdated"].is_string());
     }
     
     //------------------------------------------------------------------------
@@ -227,23 +188,21 @@ namespace Dwm {
     //------------------------------------------------------------------------
     FetchedEntryMap Fetcher::GetEntries(const vector<Ipv4Address> & addrs)
     {
-      FetchedEntryMap  entryMap;
-      if (_rdapSocket) {
-        RDAP::RequestMessage          rdapReq(addrs);
-        RDAP::ResponseMessage         rdapResp;
-        if (RequestResponse(rdapReq, rdapResp)) {
-          const Json::Value  & jv = rdapResp.Json();
-          if ((! jv.empty()) && jv.isArray() && (jv.size() > 0)) {
-            DateTime  dt;
-            for (int j = 0; j < jv.size(); ++j) {
-              if (ResponseEntryHasData(jv[j])) {
-                Ipv4Address addr(jv[j]["ipv4addr"].asString());
-                Ipv4Prefix  pfx(jv[j]["prefix"].asString());
-                dt.Parse("%Y-%m-%d %H:%M", jv[j]["lastUpdated"].asString());
-                FetchedEntry  fe(pfx, jv[j]["country"].asString(),
-                                 dt.GetTimeValue64());
-                entryMap[addr] = fe;
-              }
+      FetchedEntryMap        entryMap;
+      RDAP::RequestMessage   rdapReq(addrs);
+      RDAP::ResponseMessage  rdapResp;
+      if (RequestResponse(rdapReq, rdapResp)) {
+        const nlohmann::json  & jv = rdapResp.Json();
+        if ((! jv.empty()) && jv.is_array() && (jv.size() > 0)) {
+          DateTime  dt;
+          for (int j = 0; j < jv.size(); ++j) {
+            if (ResponseEntryHasData(jv[j])) {
+              Ipv4Address addr(jv[j]["ipv4addr"].get<string>());
+              Ipv4Prefix  pfx(jv[j]["prefix"].get<string>());
+              dt.Parse("%Y-%m-%d %H:%M", jv[j]["lastUpdated"].get<string>());
+              FetchedEntry  fe(pfx, jv[j]["country"].get<string>(),
+                               dt.GetTimeValue64());
+              entryMap[addr] = fe;
             }
           }
         }
@@ -259,7 +218,7 @@ namespace Dwm {
       pair<bool,FetchedEntry>  rc;
       rc.first = false;
       vector<Ipv4Address>  addrs = { addr };
-      FetchedEntryMap  &&entries = GetEntries(addrs);
+      FetchedEntryMap  entries = GetEntries(addrs);
       if (! entries.empty()) {
         rc.first = true;
         rc.second = entries.begin()->second;
@@ -272,13 +231,10 @@ namespace Dwm {
     //------------------------------------------------------------------------
     void Fetcher::CloseSession()
     {
-      _rdapSocket.Close();
-      _agreedKey.assign(_agreedKey.size(), '\0');
+      _peer.Disconnect();
       return;
     }
     
-    
-    
   }  // namespace RDAP
 
 }  // namespace Dwm
