@@ -1,6 +1,6 @@
 //===========================================================================
 // @(#) $Name:$
-// @(#) $Id: DwmRDAPQuery.cc 8946 2017-03-31 20:50:31Z dwm $
+// @(#) $Id: DwmRDAPQuery.cc 12078 2022-11-26 03:33:48Z dwm $
 //===========================================================================
 //  Copyright (c) Daniel W. McRobb 2017
 //  All rights reserved.
@@ -44,42 +44,19 @@
 #include <regex>
 #include <string>
 
-#include <Poco/Net/PrivateKeyPassphraseHandler.h>
-#include <Poco/Net/HTTPClientSession.h>
-#include <Poco/Net/HTTPSClientSession.h>
-#include <Poco/Net/HTTPRequest.h>
-#include <Poco/Net/HTTPResponse.h>
-#include <Poco/Net/SSLManager.h>
-#include <Poco/Net/ConsoleCertificateHandler.h>
-#include <Poco/URI.h>
-
 #include "DwmSvnTag.hh"
+#include "DwmWebUtils.hh"
 #include "DwmRDAPBootstrap.hh"
 #include "DwmRDAPQuery.hh"
 
-static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwmRDAP/tags/libDwmRDAP-0.2.1/src/DwmRDAPQuery.cc 8946 $");
+static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwmRDAP/tags/libDwmRDAP-0.3.3/src/DwmRDAPQuery.cc 12078 $");
 
 using namespace std;
-using Poco::URI;
-using Poco::Net::HTTPClientSession;
-using Poco::Net::HTTPSClientSession;
-using Poco::Net::HTTPMessage;
-using Poco::Net::HTTPRequest;
-using Poco::Net::HTTPResponse;
-using Poco::Net::Context;
 
 namespace Dwm {
 
   namespace RDAP {
 
-    //------------------------------------------------------------------------
-    //!  
-    //------------------------------------------------------------------------
-    static Context::Ptr g_context =
-      new Context(Context::CLIENT_USE, "", "", "",
-                  Context::VERIFY_NONE, 9, false,
-                  "ALL:!ADH:!LOW:!EXP:!MD5:@STRENGTH");
-    
     //------------------------------------------------------------------------
     //!  
     //------------------------------------------------------------------------
@@ -102,35 +79,12 @@ namespace Dwm {
     {
       Response  rc;
       if (! _uristr.empty()) {
-        Poco::URI    uri(_uristr);
-        std::string  host(uri.getHost());
-        std::string  path(uri.getPathAndQuery());
-        HTTPClientSession    *sess;
-        if (uri.getScheme() == "https") {
-          sess = new HTTPSClientSession(host, uri.getPort(), g_context);
-        }
-        else {
-          sess = new HTTPClientSession(host);
-        }
-        HTTPRequest  req(HTTPRequest::HTTP_GET, path, HTTPMessage::HTTP_1_1);
-        try {
-          ostream & os = sess->sendRequest(req);
-          if (os) {
-            HTTPResponse  resp;
-            istream  & is = sess->receiveResponse(resp);
-            Json::Reader  reader;
-            if (reader.parse(is, rc)) {
-              FixIpv4Stupidity(rc["startAddress"]);
-              FixIpv4Stupidity(rc["endAddress"]);
-            }
+        if (WebUtils::GetJson(_uristr, rc)) {
+          if (! rc.is_discarded()) {
+            FixIpv4Stupidity(rc["startAddress"]);
+            FixIpv4Stupidity(rc["endAddress"]);
           }
         }
-        catch (Poco::Exception &ex) {
-          cerr << "Exception, URI "
-               << uri.toString() << ", " << ex.className() << ", "
-               << ex.name() << ", " << ex.displayText() << "\n";
-        }
-        delete sess;
       }
       return rc;
     }
@@ -162,13 +116,13 @@ namespace Dwm {
     //------------------------------------------------------------------------
     //!  
     //------------------------------------------------------------------------
-    void Query::FixIpv4Stupidity(Json::Value & jv)
+    void Query::FixIpv4Stupidity(nlohmann::json & jv)
     {
       string    rc;
-      if (jv.isString() && (! jv.asString().empty())) {
+      if (jv.is_string() && (! jv.get<string>().empty())) {
         regex  rgx("(0*)([0-9]+)", regex::ECMAScript|regex::optimize);
-        rc = regex_replace(jv.asString(), rgx, "$2");
-        jv = Json::Value(rc);
+        rc = regex_replace(jv.get<string>(), rgx, "$2");
+        jv = rc;
       }
       return;
     }
