@@ -1,6 +1,6 @@
 //===========================================================================
 // @(#) $Name:$
-// @(#) $Id: DwmRDAPQuerySessions.cc 9306 2017-05-08 09:04:02Z dwm $
+// @(#) $Id: DwmRDAPQuerySessions.cc 12078 2022-11-26 03:33:48Z dwm $
 //===========================================================================
 //  Copyright (c) Daniel W. McRobb 2017
 //  All rights reserved.
@@ -43,22 +43,13 @@
 
 #include "DwmSvnTag.hh"
 #include "DwmSysLogger.hh"
+#include "DwmWebUtils.hh"
+#include "DwmWebUtilsUrl.hh"
 #include "DwmRDAPQuerySessions.hh"
 
-#include <Poco/Net/HTTPSClientSession.h>
-#include <Poco/Net/HTTPRequest.h>
-#include <Poco/Net/HTTPResponse.h>
-#include <Poco/URI.h>
-
-static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwmRDAP/tags/libDwmRDAP-0.2.1/src/DwmRDAPQuerySessions.cc 9306 $");
+static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwmRDAP/tags/libDwmRDAP-0.3.3/src/DwmRDAPQuerySessions.cc 12078 $");
 
 using namespace std;
-using Poco::Net::Context;
-using Poco::Net::HTTPClientSession;
-using Poco::Net::HTTPSClientSession;
-using Poco::Net::HTTPMessage;
-using Poco::Net::HTTPRequest;
-using Poco::Net::HTTPResponse;
 
 namespace Dwm {
 
@@ -68,11 +59,7 @@ namespace Dwm {
     //!  
     //------------------------------------------------------------------------
     QuerySessions::QuerySessions()
-        : _sessions()
     {
-      _context = new Context(Context::CLIENT_USE, "", "", "",
-                             Context::VERIFY_NONE, 9, false,
-                             "ALL:!ADH:!LOW:!EXP:!MD5:@STRENGTH");
     }
     
     //------------------------------------------------------------------------
@@ -80,36 +67,29 @@ namespace Dwm {
     //------------------------------------------------------------------------
     QuerySessions::~QuerySessions()
     {
-      for (auto sess : _sessions) {
-        delete sess.second;
-        sess.second = 0;
-      }
-      _sessions.clear();
-      //      delete _context;
     }
 
     //------------------------------------------------------------------------
     //!  
     //------------------------------------------------------------------------
-    void QuerySessions::FindVcardArrays(const Json::Value & jv,
-                                        vector<Json::Value> & vcardArrays)
+    void QuerySessions::FindVcardArrays(const nlohmann::json & jv,
+                                        vector<nlohmann::json> & vcardArrays)
     {
-      if (jv.isObject()) {
-        if (jv.isMember("vcardArray") && jv["vcardArray"].isArray()) {
+      if (jv.is_object()) {
+        if ((jv.find("vcardArray") != jv.end())
+            && jv["vcardArray"].is_array()) {
           vcardArrays.push_back(jv["vcardArray"]);
         }
-        vector<string>  &&memberNames = jv.getMemberNames();
-        remove_if(memberNames.begin(), memberNames.end(),
-                  [&] (const string & name)
-                  { return (name == "vcardArray"); });
-        for (auto mn : memberNames) {
-          FindVcardArrays(jv[mn], vcardArrays);
+        for (auto & el : jv.items()) {
+          if (el.key() != "vcardArray") {
+            FindVcardArrays(jv[el.key()], vcardArrays);
+          }
         }
       }
-      else if (jv.isArray()) {
+      else if (jv.is_array()) {
         for (int i = 0; i < jv.size(); ++i) {
-          if (jv[i].isObject() && jv[i].isMember("vcardArray")
-              && jv[i]["vcardArray"].isArray()) {
+          if (jv[i].is_object() && (jv[i].find("vcardArray") != jv[i].end())
+              && jv[i]["vcardArray"].is_array()) {
             vcardArrays.push_back(jv[i]["vcardArray"]);
           }
           FindVcardArrays(jv[i], vcardArrays);
@@ -121,7 +101,7 @@ namespace Dwm {
     //------------------------------------------------------------------------
     //!  
     //------------------------------------------------------------------------
-    string QuerySessions::FindCountryInVcard(const Json::Value & jv)
+    string QuerySessions::FindCountryInVcard(const nlohmann::json & jv)
     {
       static const map<string,string>  ccodeMap = {
         { "ANGUILLA",                             "AI" },
@@ -155,20 +135,20 @@ namespace Dwm {
         { "VIRGIN ISLANDS (U.S.)",                "VI" }
       };
       
-      vector<Json::Value>  vcardArrays;
+      vector<nlohmann::json>  vcardArrays;
       FindVcardArrays(jv, vcardArrays);
       for (auto vca : vcardArrays) {
         for (int vi = 0; vi < vca.size(); ++vi) {
-          const Json::Value &  vc = vca[vi];
-          if (vc.isArray()) {
+          const nlohmann::json &  vc = vca[vi];
+          if (vc.is_array()) {
             for (int vci = 0; vci < vc.size(); ++vci) {
-              if (vc[vci].isArray()) {
-                const Json::Value & vcm = vc[vci];
+              if (vc[vci].is_array()) {
+                const nlohmann::json & vcm = vc[vci];
                 for (int vcmi = 0; vcmi < vcm.size(); ++vcmi) {
-                  if (vcm[vcmi].isObject()) {
-                    if (vcm[vcmi].isMember("label")
-                        && vcm[vcmi]["label"].isString()) {
-                      string  label = vcm[vcmi]["label"].asString();
+                  if (vcm[vcmi].is_object()) {
+                    if ((vcm[vcmi].find("label") != vcm[vcmi].end())
+                        && vcm[vcmi]["label"].is_string()) {
+                      string  label = vcm[vcmi]["label"].get<string>();
                       string::size_type  idx = label.find_last_of('\n');
                       if ((idx != string::npos) && (idx < (label.size() - 1))) {
                         auto  cc = ccodeMap.find(label.substr(idx+1));
@@ -195,80 +175,23 @@ namespace Dwm {
     RDAP::IPv4Response QuerySessions::Execute(const Query & query)
     {
       RDAP::IPv4Response  rc;
-      HTTPClientSession  *sess = GetSession(query);
-      if (sess) {
-        Poco::URI    uri(query.Uri());
-        HTTPRequest  req(HTTPRequest::HTTP_GET, uri.getPathAndQuery(),
-                         HTTPMessage::HTTP_1_1);
-        try {
-          ostream & os = sess->sendRequest(req);
-          if (os) {
-            HTTPResponse  resp;
-            istream  & is = sess->receiveResponse(resp);
-            Json::Reader  reader;
-            if (reader.parse(is, rc)) {
-              Query::FixIpv4Stupidity(rc["startAddress"]);
-              Query::FixIpv4Stupidity(rc["endAddress"]);
-              if (uri.getHost().find_last_of("arin.net") != string::npos) {
-                if ((! rc.isMember("country"))
-                    || (rc["country"].isString()
-                        && rc["country"].asString().empty())) {
-                  //  Fudge for more ARIN stupidity
-                  string  &&vcardCcode = FindCountryInVcard(rc);
-                  if (! vcardCcode.empty()) {
-                    rc["country"] = vcardCcode;
-                  }
-                  else {
-                    rc["country"] = "US";
-                  }
-                }
-              }
+      if (WebUtils::GetJson(query.Uri(), rc)) {
+        Query::FixIpv4Stupidity(rc["startAddress"]);
+        Query::FixIpv4Stupidity(rc["endAddress"]);
+        WebUtils::Url  url(query.Uri());
+        if (url.Host().find_last_of("arin.net") != string::npos) {
+          if ((rc.find("country") == rc.end())
+              || (rc["country"].is_string()
+                  && rc["country"].get<string>().empty())) {
+            //  Fudge for more ARIN stupidity
+            string  &&vcardCcode = FindCountryInVcard(rc);
+            if (! vcardCcode.empty()) {
+              rc["country"] = vcardCcode;
             }
             else {
-              Syslog(LOG_ERR, "Failed to parse response from %s", uri.getHost().c_str());
+              rc["country"] = "US";
             }
           }
-          else {
-            Syslog(LOG_ERR, "%s sendRequest failed", uri.getHost().c_str());
-          }
-        }
-        catch (Poco::Exception &ex) {
-          Syslog(LOG_ERR, "Exception %s for URI %s: %s",
-                 ex.name(), uri.toString().c_str(),
-                 ex.displayText().c_str());
-        }
-      }
-      else {
-      }
-      
-      return rc;
-    }
-    
-    //------------------------------------------------------------------------
-    //!  
-    //------------------------------------------------------------------------
-    HTTPClientSession *QuerySessions::GetSession(const Query & query)
-    {
-      HTTPClientSession  *rc = (HTTPClientSession *)nullptr;
-      Poco::URI  uri(query.Uri());
-      string     sessKey(uri.getScheme() + "://" + uri.getHost() + ":"
-                         + to_string(uri.getPort()));
-      auto  sit = _sessions.find(sessKey);
-      if (sit != _sessions.end()) {
-        rc = sit->second;
-      }
-      else {
-        HTTPClientSession  *sess;
-        if (uri.getScheme() == "https") {
-          rc = new HTTPSClientSession(uri.getHost(), uri.getPort(),
-                                        _context);
-        }
-        else if (uri.getScheme() == "http") {
-          rc = new HTTPClientSession(uri.getHost());
-        }
-        if (rc != nullptr) {
-          rc->setKeepAlive(true);
-          _sessions[sessKey] = rc;
         }
       }
       return rc;
