@@ -1,8 +1,8 @@
 //===========================================================================
 // @(#) $Name:$
-// @(#) $Id: DwmRDAPRequestMessage.cc 8926 2017-03-29 05:40:25Z dwm $
+// @(#) $Id: DwmRDAPRequestMessage.cc 12117 2022-12-11 04:34:00Z dwm $
 //===========================================================================
-//  Copyright (c) Daniel W. McRobb 2017
+//  Copyright (c) Daniel W. McRobb 2017, 2022
 //  All rights reserved.
 //
 //  Redistribution and use in source and binary forms, with or without
@@ -36,14 +36,14 @@
 
 //---------------------------------------------------------------------------
 //!  \file DwmRDAPRequestMessage.cc
-//!  \brief NOT YET DOCUMENTED
+//!  \brief Dwm::RDAP::RequestMessage class implementation
 //---------------------------------------------------------------------------
 
+#include "DwmStreamIO.hh"
 #include "DwmSvnTag.hh"
-#include "DwmAuthSymCryptoMessage.hh"
 #include "DwmRDAPRequestMessage.hh"
 
-static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwmRDAP/tags/libDwmRDAP-0.2.1/src/DwmRDAPRequestMessage.cc 8926 $");
+static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwmRDAP/tags/libDwmRDAP-0.3.3/src/DwmRDAPRequestMessage.cc 12117 $");
 
 using namespace std;
 
@@ -63,14 +63,14 @@ namespace Dwm {
     //------------------------------------------------------------------------
     //!  
     //------------------------------------------------------------------------
-    RequestMessage::RequestMessage(const Json::Value & req)
+    RequestMessage::RequestMessage(const nlohmann::json & req)
         : _value(req)
     {}
 
     //------------------------------------------------------------------------
     //!  
     //------------------------------------------------------------------------
-    RequestMessage::RequestMessage(const Json::Value && req)
+    RequestMessage::RequestMessage(const nlohmann::json && req)
         : _value(std::move(req))
     {
     }
@@ -86,20 +86,30 @@ namespace Dwm {
         _value["ipv4addrs"][i] = (string)addrs[i];
       }
     }
-    
+
     //------------------------------------------------------------------------
     //!  
     //------------------------------------------------------------------------
-    bool RequestMessage::Read(int fd, const string & secret)
+    std::istream & RequestMessage::Read(std::istream & is)
+    {
+      _value.clear();
+      if (is) {
+        _value = nlohmann::json::parse(is, nullptr, false);
+      }
+      return is;
+    }
+
+    //------------------------------------------------------------------------
+    //!  
+    //------------------------------------------------------------------------
+    bool RequestMessage::Read(Credence::Peer & peer)
     {
       bool  rc = false;
       _value.clear();
-      if (fd >= 0) {
-        Auth::SymCrypto::Message  msg(secret);
-        if (msg.Read(fd) > 0) {
-          Json::Reader  jsonReader;
-          rc = jsonReader.parse(msg.Value(), _value);
-        }
+      std::string  s;
+      if (peer.Receive(s)) {
+        _value = nlohmann::json::parse(s, nullptr, false);
+        rc = (! _value.is_discarded());
       }
       return rc;
     }
@@ -107,23 +117,29 @@ namespace Dwm {
     //------------------------------------------------------------------------
     //!  
     //------------------------------------------------------------------------
-    bool RequestMessage::Write(int fd, const string & secret) const
+    std::ostream & RequestMessage::Write(std::ostream & os) const
+    {
+      if (os) {
+        os << _value.dump();
+      }
+      return os;
+    }
+
+    //------------------------------------------------------------------------
+    //!  
+    //------------------------------------------------------------------------
+    bool RequestMessage::Write(Credence::Peer & peer) const
     {
       bool  rc = false;
-      if (fd >= 0) {
-        Json::FastWriter  fw;
-        Auth::SymCrypto::Message  msg(secret, fw.write(_value));
-        if (msg.Write(fd) == msg.StreamedLength()) {
-          rc = true;
-        }
-      }
+      std::string  s = _value.dump();
+      rc = peer.Send(s);
       return rc;
     }
     
     //------------------------------------------------------------------------
     //!  
     //------------------------------------------------------------------------
-    const Json::Value & RequestMessage::Json() const
+    const nlohmann::json & RequestMessage::Json() const
     {
       return _value;
     }
