@@ -1,6 +1,6 @@
 //===========================================================================
 // @(#) $Name:$
-// @(#) $Id: DwmRDAPResponse.cc 8926 2017-03-29 05:40:25Z dwm $
+// @(#) $Id: DwmRDAPResponse.cc 12077 2022-11-25 18:56:56Z dwm $
 //===========================================================================
 //  Copyright (c) Daniel W. McRobb 2017
 //  All rights reserved.
@@ -43,7 +43,7 @@
 #include "DwmSvnTag.hh"
 #include "DwmRDAPResponse.hh"
 
-static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwmRDAP/tags/libDwmRDAP-0.2.1/src/DwmRDAPResponse.cc 8926 $");
+static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwmRDAP/tags/libDwmRDAP-0.3.3/src/DwmRDAPResponse.cc 12077 $");
 
 using namespace std;
 
@@ -59,14 +59,14 @@ namespace Dwm {
       DateTime  dt = DateTime(TimeValue64(0,0));
       DateTime  tmpdt(false);
   
-      if (this->isMember("events")) {
-        if ((*this)["events"].isArray()) {
+      if (this->find("events") != this->end()) {
+        if ((*this)["events"].is_array()) {
           for (int e = 0; e < (*this)["events"].size(); ++e) {
-            if ((*this)["events"][e].isMember("eventAction")
-                && (*this)["events"][e].isMember("eventDate")
-                && ((*this)["events"][e]["eventAction"].asString()
+            if (((*this)["events"][e].find("eventAction") != (*this)["events"][e].end())
+                && ((*this)["events"][e].find("eventDate") != (*this)["events"][e].end())
+                && ((*this)["events"][e]["eventAction"].get<string>()
                     == "last changed")) {
-              if (tmpdt.Parse((*this)["events"][e]["eventDate"].asString(),
+              if (tmpdt.Parse((*this)["events"][e]["eventDate"].get<string>(),
                               "%Y-%m-%dT%H:%M:%S")) {
                 if (dt < tmpdt) {
                   dt = tmpdt;
@@ -86,15 +86,15 @@ namespace Dwm {
     {
       pair<Ipv4Address,Ipv4Address>  rc(INADDR_ANY, INADDR_ANY);
       
-      const Json::Value  & jv = *this;
-      if (jv.isMember("startAddress")) {
-        if (jv["startAddress"].isString()
-            && (! jv["startAddress"].asString().empty())) {
-          if (jv.isMember("endAddress")) {
-            if (jv["endAddress"].isString()
-                && (! jv["endAddress"].asString().empty())) {
-              Ipv4Prefix  startpfx(jv["startAddress"].asString());
-              Ipv4Prefix  endpfx(jv["endAddress"].asString());
+      const nlohmann::json  & jv = *this;
+      if (jv.find("startAddress") != jv.end()) {
+        if (jv["startAddress"].is_string()
+            && (! jv["startAddress"].get<string>().empty())) {
+          if (jv.find("endAddress") != jv.end()) {
+            if (jv["endAddress"].is_string()
+                && (! jv["endAddress"].get<string>().empty())) {
+              Ipv4Prefix  startpfx(jv["startAddress"].get<string>());
+              Ipv4Prefix  endpfx(jv["endAddress"].get<string>());
               rc.first = startpfx.FirstAddress();
               rc.second = endpfx.LastAddress();
             }
@@ -123,10 +123,10 @@ namespace Dwm {
     string IPv4Response::Country() const
     {
       string  rc;
-      const Json::Value  & jv = *this;
-      if (jv.isMember("country")
-          && jv["country"].isString()) {
-        string  s = jv["country"].asString();
+      const nlohmann::json  & jv = *this;
+      if ((jv.find("country") != jv.end())
+          && jv["country"].is_string()) {
+        string  s = jv["country"].get<string>();
         if (s.length() == 2) {
           for (auto & c : s) { c = toupper(c); }
           rc = s;
