@@ -1,8 +1,8 @@
 //===========================================================================
 // @(#) $Name:$
-// @(#) $Id: DwmRDAPResponseMessage.cc 8926 2017-03-29 05:40:25Z dwm $
+// @(#) $Id: DwmRDAPResponseMessage.cc 12118 2022-12-11 04:35:10Z dwm $
 //===========================================================================
-//  Copyright (c) Daniel W. McRobb 2017
+//  Copyright (c) Daniel W. McRobb 2017, 2022
 //  All rights reserved.
 //
 //  Redistribution and use in source and binary forms, with or without
@@ -36,14 +36,14 @@
 
 //---------------------------------------------------------------------------
 //!  \file DwmRDAPResponseMessage.cc
-//!  \brief NOT YET DOCUMENTED
+//!  \brief Dwm::RDAP::ResponseMessage class implementation
 //---------------------------------------------------------------------------
 
+#include "DwmStreamIO.hh"
 #include "DwmSvnTag.hh"
-#include "DwmAuthSymCryptoMessage.hh"
 #include "DwmRDAPResponseMessage.hh"
 
-static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwmRDAP/tags/libDwmRDAP-0.2.1/src/DwmRDAPResponseMessage.cc 8926 $");
+static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwmRDAP/tags/libDwmRDAP-0.3.3/src/DwmRDAPResponseMessage.cc 12118 $");
 
 using namespace std;
 
@@ -61,21 +61,21 @@ namespace Dwm {
     //------------------------------------------------------------------------
     //!  
     //------------------------------------------------------------------------
-    ResponseMessage::ResponseMessage(const Json::Value & value)
+    ResponseMessage::ResponseMessage(const nlohmann::json & value)
         : _value(value)
     {}
 
     //------------------------------------------------------------------------
     //!  
     //------------------------------------------------------------------------
-    ResponseMessage::ResponseMessage(const Json::Value && value)
+    ResponseMessage::ResponseMessage(const nlohmann::json && value)
         : _value(std::move(value))
     {}
 
     //------------------------------------------------------------------------
     //!  
     //------------------------------------------------------------------------
-    const Json::Value & ResponseMessage::Json() const
+    const nlohmann::json & ResponseMessage::Json() const
     {
       return _value;
     }
@@ -83,7 +83,7 @@ namespace Dwm {
     //------------------------------------------------------------------------
     //!  
     //------------------------------------------------------------------------
-    const Json::Value & ResponseMessage::Json(const Json::Value & value)
+    const nlohmann::json & ResponseMessage::Json(const nlohmann::json & value)
     {
       _value = value;
       return _value;
@@ -92,17 +92,39 @@ namespace Dwm {
     //------------------------------------------------------------------------
     //!  
     //------------------------------------------------------------------------
-    bool ResponseMessage::Read(int fd, const string & secret)
+    std::istream & ResponseMessage::Read(std::istream & is)
+    {
+      _value.clear();
+      _value = "";
+      if (is) {
+        _value = nlohmann::json::parse(is, nullptr, false);
+      }
+      return is;
+    }
+    
+    //------------------------------------------------------------------------
+    //!  
+    //------------------------------------------------------------------------
+    std::ostream & ResponseMessage::Write(std::ostream & os) const
+    {
+      if (os) {
+        os << _value.dump();
+      }
+      return os;
+    }
+
+    //------------------------------------------------------------------------
+    //!  
+    //------------------------------------------------------------------------
+    bool ResponseMessage::Read(Credence::Peer & peer)
     {
       bool  rc = false;
       _value.clear();
       _value = "";
-      if (fd >= 0) {
-        Auth::SymCrypto::Message  msg(secret);
-        if (msg.Read(fd) > 0) {
-          Json::Reader  jsonReader;
-          rc = jsonReader.parse(msg.Value(), _value);
-        }
+      std::string  s;
+      if (peer.Receive(s)) {
+        _value = nlohmann::json::parse(s, nullptr, false);
+        rc = (! _value.is_discarded());
       }
       return rc;
     }
@@ -110,20 +132,12 @@ namespace Dwm {
     //------------------------------------------------------------------------
     //!  
     //------------------------------------------------------------------------
-    bool ResponseMessage::Write(int fd, const string & secret) const
+    bool ResponseMessage::Write(Credence::Peer & peer) const
     {
-      bool  rc = false;
-      if (fd >= 0) {
-        Json::FastWriter  fw;
-        Auth::SymCrypto::Message  msg(secret, fw.write(_value));
-        if (msg.Write(fd) == msg.StreamedLength()) {
-          rc = true;
-        }
-      }
-      return rc;
+      std::string  s = _value.dump();
+      return peer.Send(s);
     }
     
-    
   }  // namespace RDAP
 
 }  // namespace Dwm
