@@ -1,6 +1,6 @@
 //===========================================================================
 // @(#) $Name:$
-// @(#) $Id: TestRDAPQuery.cc 9458 2017-06-06 05:08:27Z dwm $
+// @(#) $Id: TestRDAPQuery.cc 12239 2023-10-26 17:41:12Z dwm $
 //===========================================================================
 //  Copyright (c) Daniel W. McRobb 2017
 //  All rights reserved.
@@ -41,8 +41,6 @@
 
 #include <iomanip>
 #include <iostream>
-#include <Poco/Net/SSLManager.h>
-#include <Poco/URI.h>
 
 #include "DwmIpv4Prefix.hh"
 #include "DwmOptArgs.hh"
@@ -51,7 +49,7 @@
 #include "DwmRDAPBootstrap.hh"
 #include "DwmRDAPQuery.hh"
 
-static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwmRDAP/tags/libDwmRDAP-0.2.1/tests/TestRDAPQuery.cc 9458 $");
+static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwmRDAP/tags/libDwmRDAP-0.3.3/tests/TestRDAPQuery.cc 12239 $");
 
 using namespace std;
 using namespace Dwm;
@@ -95,10 +93,7 @@ int main(int argc, char *argv[])
   Dwm::OptArgs  optargs;
   optargs.AddOptArg("p", "print", false, "false", "print some query results");
   optargs.Parse(argc, argv);
-#if (POCO_VERSION >= 0x01040200)
-  Poco::Net::initializeSSL();
-#endif
-  RDAP::Bootstrap::Load("file:./ipv4.json");
+  RDAP::Bootstrap::Load("./ipv4.json");
 
   TestQuery("192.172.226.1", optargs.Get<bool>('p'));  // ARIN
   TestQuery("222.214.218.1", optargs.Get<bool>('p'));  // APNIC
